use owo_colors::{
    AnsiColors,
    DynColors::{self, Ansi, Rgb},
};
use std::fmt;
use std::fmt::Write;
use strum::EnumIter;

pub struct Colors {
    basic_colors: Vec<DynColors>,
    true_colors: Option<Vec<DynColors>>,
}

const DEFAULT_CHIP_ICON: char = '\u{25CF}';

#[derive(Clone, PartialEq, Eq, Debug, clap::ValueEnum)]
pub enum LanguageType {
    Programming,
    Markup,
    Prose,
    Data,
}

#[derive(Clone, Copy, PartialEq, Eq, Hash, EnumIter, clap::ValueEnum, Debug, Serialize)]
#[allow(clippy::upper_case_acronyms)]
#[clap(rename_all = "lowercase")]
pub enum Language {
    ABNF,
    Abap,
    Ada,
    Agda,
    Arduino,
    Assembly,
    AutoHotKey,
    Bash,
    C,
    CMake,
    #[clap(name="c#")]CSharp,
    Ceylon,
    Clojure,
    CoffeeScript,
    ColdFusion,
    Coq,
    #[clap(name="c++")]Cpp,
    Crystal,
    Css,
    D,
    Dart,
    Dockerfile,
    #[clap(name="emacs-lisp")]Elisp,
    Elixir,
    Elm,
    Emojicode,
    Erlang,
    #[clap(name="f#")]FSharp,
    Fish,
    Forth,
    #[clap(name="fortran")]FortranLegacy,
    FortranModern,
    GdScript,
    Glsl,
    Go,
    Graphql,
    Groovy,
    Haskell,
    Haxe,
    Hcl,
    Hlsl,
    HolyC,
    Html,
    Idris,
    Java,
    JavaScript,
    Json,
    Jsonnet,
    Jsx,
    Julia,
    #[clap(name="jupyter-notebooks")]Jupyter,
    Kotlin,
    LLVM,
    Lisp,
    Lua,
    Makefile,
    Markdown,
    Nim,
    Nix,
    OCaml,
    #[clap(name="objective-c")]ObjectiveC,
    Odin,
    Org,
    Oz,
    Pascal,
    Perl,
    #[clap(name="raku")]Perl6,
    Php,
    PowerShell,
    Processing,
    Prolog,
    #[clap(name="protocol-buffers")]Protobuf,
    PureScript,
    Python,
    Qml,
    R,
    Racket,
    Renpy,
    Ruby,
    Rust,
    Sass,
    Scala,
    Scheme,
    #[clap(name="shell")]Sh,
    Solidity,
    Sql,
    Svelte,
    Svg,
    Swift,
    SystemVerilog,
    Tcl,
    Tex,
    Toml,
    Tsx,
    TypeScript,
    Vala,
    Verilog,
    Vhdl,
    VimScript,
    VisualBasic,
    Vue,
    WebAssembly,
    Wolfram,
    XSL,
    Xaml,
    Xml,
    Yaml,
    Zig,
    Zsh,
    
}

impl fmt::Display for Language {
    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
        match self {
            Self::ABNF => write!(f, "{}", tokei::LanguageType::ABNF.name()),
            Self::Abap => write!(f, "{}", tokei::LanguageType::Abap.name()),
            Self::Ada => write!(f, "{}", tokei::LanguageType::Ada.name()),
            Self::Agda => write!(f, "{}", tokei::LanguageType::Agda.name()),
            Self::Arduino => write!(f, "{}", tokei::LanguageType::Arduino.name()),
            Self::Assembly => write!(f, "{}", tokei::LanguageType::Assembly.name()),
            Self::AutoHotKey => write!(f, "{}", tokei::LanguageType::AutoHotKey.name()),
            Self::Bash => write!(f, "{}", tokei::LanguageType::Bash.name()),
            Self::C => write!(f, "{}", tokei::LanguageType::C.name()),
            Self::CMake => write!(f, "{}", tokei::LanguageType::CMake.name()),
            Self::CSharp => write!(f, "{}", tokei::LanguageType::CSharp.name()),
            Self::Ceylon => write!(f, "{}", tokei::LanguageType::Ceylon.name()),
            Self::Clojure => write!(f, "{}", tokei::LanguageType::Clojure.name()),
            Self::CoffeeScript => write!(f, "{}", tokei::LanguageType::CoffeeScript.name()),
            Self::ColdFusion => write!(f, "{}", tokei::LanguageType::ColdFusion.name()),
            Self::Coq => write!(f, "{}", tokei::LanguageType::Coq.name()),
            Self::Cpp => write!(f, "{}", tokei::LanguageType::Cpp.name()),
            Self::Crystal => write!(f, "{}", tokei::LanguageType::Crystal.name()),
            Self::Css => write!(f, "{}", tokei::LanguageType::Css.name()),
            Self::D => write!(f, "{}", tokei::LanguageType::D.name()),
            Self::Dart => write!(f, "{}", tokei::LanguageType::Dart.name()),
            Self::Dockerfile => write!(f, "{}", tokei::LanguageType::Dockerfile.name()),
            Self::Elisp => write!(f, "{}", tokei::LanguageType::Elisp.name()),
            Self::Elixir => write!(f, "{}", tokei::LanguageType::Elixir.name()),
            Self::Elm => write!(f, "{}", tokei::LanguageType::Elm.name()),
            Self::Emojicode => write!(f, "{}", tokei::LanguageType::Emojicode.name()),
            Self::Erlang => write!(f, "{}", tokei::LanguageType::Erlang.name()),
            Self::FSharp => write!(f, "{}", tokei::LanguageType::FSharp.name()),
            Self::Fish => write!(f, "{}", tokei::LanguageType::Fish.name()),
            Self::Forth => write!(f, "{}", tokei::LanguageType::Forth.name()),
            Self::FortranLegacy => write!(f, "{}", tokei::LanguageType::FortranLegacy.name()),
            Self::FortranModern => write!(f, "{}", tokei::LanguageType::FortranModern.name()),
            Self::GdScript => write!(f, "{}", tokei::LanguageType::GdScript.name()),
            Self::Glsl => write!(f, "{}", tokei::LanguageType::Glsl.name()),
            Self::Go => write!(f, "{}", tokei::LanguageType::Go.name()),
            Self::Graphql => write!(f, "{}", tokei::LanguageType::Graphql.name()),
            Self::Groovy => write!(f, "{}", tokei::LanguageType::Groovy.name()),
            Self::Haskell => write!(f, "{}", tokei::LanguageType::Haskell.name()),
            Self::Haxe => write!(f, "{}", tokei::LanguageType::Haxe.name()),
            Self::Hcl => write!(f, "{}", tokei::LanguageType::Hcl.name()),
            Self::Hlsl => write!(f, "{}", tokei::LanguageType::Hlsl.name()),
            Self::HolyC => write!(f, "{}", tokei::LanguageType::HolyC.name()),
            Self::Html => write!(f, "{}", tokei::LanguageType::Html.name()),
            Self::Idris => write!(f, "{}", tokei::LanguageType::Idris.name()),
            Self::Java => write!(f, "{}", tokei::LanguageType::Java.name()),
            Self::JavaScript => write!(f, "{}", tokei::LanguageType::JavaScript.name()),
            Self::Json => write!(f, "{}", tokei::LanguageType::Json.name()),
            Self::Jsonnet => write!(f, "{}", tokei::LanguageType::Jsonnet.name()),
            Self::Jsx => write!(f, "{}", tokei::LanguageType::Jsx.name()),
            Self::Julia => write!(f, "{}", tokei::LanguageType::Julia.name()),
            Self::Jupyter => write!(f, "{}", tokei::LanguageType::Jupyter.name()),
            Self::Kotlin => write!(f, "{}", tokei::LanguageType::Kotlin.name()),
            Self::LLVM => write!(f, "{}", tokei::LanguageType::LLVM.name()),
            Self::Lisp => write!(f, "{}", tokei::LanguageType::Lisp.name()),
            Self::Lua => write!(f, "{}", tokei::LanguageType::Lua.name()),
            Self::Makefile => write!(f, "{}", tokei::LanguageType::Makefile.name()),
            Self::Markdown => write!(f, "{}", tokei::LanguageType::Markdown.name()),
            Self::Nim => write!(f, "{}", tokei::LanguageType::Nim.name()),
            Self::Nix => write!(f, "{}", tokei::LanguageType::Nix.name()),
            Self::OCaml => write!(f, "{}", tokei::LanguageType::OCaml.name()),
            Self::ObjectiveC => write!(f, "{}", tokei::LanguageType::ObjectiveC.name()),
            Self::Odin => write!(f, "{}", tokei::LanguageType::Odin.name()),
            Self::Org => write!(f, "{}", tokei::LanguageType::Org.name()),
            Self::Oz => write!(f, "{}", tokei::LanguageType::Oz.name()),
            Self::Pascal => write!(f, "{}", tokei::LanguageType::Pascal.name()),
            Self::Perl => write!(f, "{}", tokei::LanguageType::Perl.name()),
            Self::Perl6 => write!(f, "{}", tokei::LanguageType::Perl6.name()),
            Self::Php => write!(f, "{}", tokei::LanguageType::Php.name()),
            Self::PowerShell => write!(f, "{}", tokei::LanguageType::PowerShell.name()),
            Self::Processing => write!(f, "{}", tokei::LanguageType::Processing.name()),
            Self::Prolog => write!(f, "{}", tokei::LanguageType::Prolog.name()),
            Self::Protobuf => write!(f, "{}", tokei::LanguageType::Protobuf.name()),
            Self::PureScript => write!(f, "{}", tokei::LanguageType::PureScript.name()),
            Self::Python => write!(f, "{}", tokei::LanguageType::Python.name()),
            Self::Qml => write!(f, "{}", tokei::LanguageType::Qml.name()),
            Self::R => write!(f, "{}", tokei::LanguageType::R.name()),
            Self::Racket => write!(f, "{}", tokei::LanguageType::Racket.name()),
            Self::Renpy => write!(f, "{}", tokei::LanguageType::Renpy.name()),
            Self::Ruby => write!(f, "{}", tokei::LanguageType::Ruby.name()),
            Self::Rust => write!(f, "{}", tokei::LanguageType::Rust.name()),
            Self::Sass => write!(f, "{}", tokei::LanguageType::Sass.name()),
            Self::Scala => write!(f, "{}", tokei::LanguageType::Scala.name()),
            Self::Scheme => write!(f, "{}", tokei::LanguageType::Scheme.name()),
            Self::Sh => write!(f, "{}", tokei::LanguageType::Sh.name()),
            Self::Solidity => write!(f, "{}", tokei::LanguageType::Solidity.name()),
            Self::Sql => write!(f, "{}", tokei::LanguageType::Sql.name()),
            Self::Svelte => write!(f, "{}", tokei::LanguageType::Svelte.name()),
            Self::Svg => write!(f, "{}", tokei::LanguageType::Svg.name()),
            Self::Swift => write!(f, "{}", tokei::LanguageType::Swift.name()),
            Self::SystemVerilog => write!(f, "{}", tokei::LanguageType::SystemVerilog.name()),
            Self::Tcl => write!(f, "{}", tokei::LanguageType::Tcl.name()),
            Self::Tex => write!(f, "{}", tokei::LanguageType::Tex.name()),
            Self::Toml => write!(f, "{}", tokei::LanguageType::Toml.name()),
            Self::Tsx => write!(f, "{}", tokei::LanguageType::Tsx.name()),
            Self::TypeScript => write!(f, "{}", tokei::LanguageType::TypeScript.name()),
            Self::Vala => write!(f, "{}", tokei::LanguageType::Vala.name()),
            Self::Verilog => write!(f, "{}", tokei::LanguageType::Verilog.name()),
            Self::Vhdl => write!(f, "{}", tokei::LanguageType::Vhdl.name()),
            Self::VimScript => write!(f, "{}", tokei::LanguageType::VimScript.name()),
            Self::VisualBasic => write!(f, "{}", tokei::LanguageType::VisualBasic.name()),
            Self::Vue => write!(f, "{}", tokei::LanguageType::Vue.name()),
            Self::WebAssembly => write!(f, "{}", tokei::LanguageType::WebAssembly.name()),
            Self::Wolfram => write!(f, "{}", tokei::LanguageType::Wolfram.name()),
            Self::XSL => write!(f, "{}", tokei::LanguageType::XSL.name()),
            Self::Xaml => write!(f, "{}", tokei::LanguageType::Xaml.name()),
            Self::Xml => write!(f, "{}", tokei::LanguageType::Xml.name()),
            Self::Yaml => write!(f, "{}", tokei::LanguageType::Yaml.name()),
            Self::Zig => write!(f, "{}", tokei::LanguageType::Zig.name()),
            Self::Zsh => write!(f, "{}", tokei::LanguageType::Zsh.name()),
            
        }
    }
}

impl From<tokei::LanguageType> for Language {
    fn from(language: tokei::LanguageType) -> Self {
        match language {
            tokei::LanguageType::ABNF => Self::ABNF,
            tokei::LanguageType::Abap => Self::Abap,
            tokei::LanguageType::Ada => Self::Ada,
            tokei::LanguageType::Agda => Self::Agda,
            tokei::LanguageType::Arduino => Self::Arduino,
            tokei::LanguageType::Assembly => Self::Assembly,
            tokei::LanguageType::AutoHotKey => Self::AutoHotKey,
            tokei::LanguageType::Bash => Self::Bash,
            tokei::LanguageType::C => Self::C,
            tokei::LanguageType::CMake => Self::CMake,
            tokei::LanguageType::CSharp => Self::CSharp,
            tokei::LanguageType::Ceylon => Self::Ceylon,
            tokei::LanguageType::Clojure => Self::Clojure,
            tokei::LanguageType::CoffeeScript => Self::CoffeeScript,
            tokei::LanguageType::ColdFusion => Self::ColdFusion,
            tokei::LanguageType::Coq => Self::Coq,
            tokei::LanguageType::Cpp => Self::Cpp,
            tokei::LanguageType::Crystal => Self::Crystal,
            tokei::LanguageType::Css => Self::Css,
            tokei::LanguageType::D => Self::D,
            tokei::LanguageType::Dart => Self::Dart,
            tokei::LanguageType::Dockerfile => Self::Dockerfile,
            tokei::LanguageType::Elisp => Self::Elisp,
            tokei::LanguageType::Elixir => Self::Elixir,
            tokei::LanguageType::Elm => Self::Elm,
            tokei::LanguageType::Emojicode => Self::Emojicode,
            tokei::LanguageType::Erlang => Self::Erlang,
            tokei::LanguageType::FSharp => Self::FSharp,
            tokei::LanguageType::Fish => Self::Fish,
            tokei::LanguageType::Forth => Self::Forth,
            tokei::LanguageType::FortranLegacy => Self::FortranLegacy,
            tokei::LanguageType::FortranModern => Self::FortranModern,
            tokei::LanguageType::GdScript => Self::GdScript,
            tokei::LanguageType::Glsl => Self::Glsl,
            tokei::LanguageType::Go => Self::Go,
            tokei::LanguageType::Graphql => Self::Graphql,
            tokei::LanguageType::Groovy => Self::Groovy,
            tokei::LanguageType::Haskell => Self::Haskell,
            tokei::LanguageType::Haxe => Self::Haxe,
            tokei::LanguageType::Hcl => Self::Hcl,
            tokei::LanguageType::Hlsl => Self::Hlsl,
            tokei::LanguageType::HolyC => Self::HolyC,
            tokei::LanguageType::Html => Self::Html,
            tokei::LanguageType::Idris => Self::Idris,
            tokei::LanguageType::Java => Self::Java,
            tokei::LanguageType::JavaScript => Self::JavaScript,
            tokei::LanguageType::Json => Self::Json,
            tokei::LanguageType::Jsonnet => Self::Jsonnet,
            tokei::LanguageType::Jsx => Self::Jsx,
            tokei::LanguageType::Julia => Self::Julia,
            tokei::LanguageType::Jupyter => Self::Jupyter,
            tokei::LanguageType::Kotlin => Self::Kotlin,
            tokei::LanguageType::LLVM => Self::LLVM,
            tokei::LanguageType::Lisp => Self::Lisp,
            tokei::LanguageType::Lua => Self::Lua,
            tokei::LanguageType::Makefile => Self::Makefile,
            tokei::LanguageType::Markdown => Self::Markdown,
            tokei::LanguageType::Nim => Self::Nim,
            tokei::LanguageType::Nix => Self::Nix,
            tokei::LanguageType::OCaml => Self::OCaml,
            tokei::LanguageType::ObjectiveC => Self::ObjectiveC,
            tokei::LanguageType::Odin => Self::Odin,
            tokei::LanguageType::Org => Self::Org,
            tokei::LanguageType::Oz => Self::Oz,
            tokei::LanguageType::Pascal => Self::Pascal,
            tokei::LanguageType::Perl => Self::Perl,
            tokei::LanguageType::Perl6 => Self::Perl6,
            tokei::LanguageType::Php => Self::Php,
            tokei::LanguageType::PowerShell => Self::PowerShell,
            tokei::LanguageType::Processing => Self::Processing,
            tokei::LanguageType::Prolog => Self::Prolog,
            tokei::LanguageType::Protobuf => Self::Protobuf,
            tokei::LanguageType::PureScript => Self::PureScript,
            tokei::LanguageType::Python => Self::Python,
            tokei::LanguageType::Qml => Self::Qml,
            tokei::LanguageType::R => Self::R,
            tokei::LanguageType::Racket => Self::Racket,
            tokei::LanguageType::Renpy => Self::Renpy,
            tokei::LanguageType::Ruby => Self::Ruby,
            tokei::LanguageType::Rust => Self::Rust,
            tokei::LanguageType::Sass => Self::Sass,
            tokei::LanguageType::Scala => Self::Scala,
            tokei::LanguageType::Scheme => Self::Scheme,
            tokei::LanguageType::Sh => Self::Sh,
            tokei::LanguageType::Solidity => Self::Solidity,
            tokei::LanguageType::Sql => Self::Sql,
            tokei::LanguageType::Svelte => Self::Svelte,
            tokei::LanguageType::Svg => Self::Svg,
            tokei::LanguageType::Swift => Self::Swift,
            tokei::LanguageType::SystemVerilog => Self::SystemVerilog,
            tokei::LanguageType::Tcl => Self::Tcl,
            tokei::LanguageType::Tex => Self::Tex,
            tokei::LanguageType::Toml => Self::Toml,
            tokei::LanguageType::Tsx => Self::Tsx,
            tokei::LanguageType::TypeScript => Self::TypeScript,
            tokei::LanguageType::Vala => Self::Vala,
            tokei::LanguageType::Verilog => Self::Verilog,
            tokei::LanguageType::Vhdl => Self::Vhdl,
            tokei::LanguageType::VimScript => Self::VimScript,
            tokei::LanguageType::VisualBasic => Self::VisualBasic,
            tokei::LanguageType::Vue => Self::Vue,
            tokei::LanguageType::WebAssembly => Self::WebAssembly,
            tokei::LanguageType::Wolfram => Self::Wolfram,
            tokei::LanguageType::XSL => Self::XSL,
            tokei::LanguageType::Xaml => Self::Xaml,
            tokei::LanguageType::Xml => Self::Xml,
            tokei::LanguageType::Yaml => Self::Yaml,
            tokei::LanguageType::Zig => Self::Zig,
            tokei::LanguageType::Zsh => Self::Zsh,
            
            _ => unimplemented!("Language {:?}", language),
        }
    }
}

impl From<Language> for tokei::LanguageType {
    fn from(language: Language) -> Self {
        match language {
            Language::ABNF => tokei::LanguageType::ABNF,
            Language::Abap => tokei::LanguageType::Abap,
            Language::Ada => tokei::LanguageType::Ada,
            Language::Agda => tokei::LanguageType::Agda,
            Language::Arduino => tokei::LanguageType::Arduino,
            Language::Assembly => tokei::LanguageType::Assembly,
            Language::AutoHotKey => tokei::LanguageType::AutoHotKey,
            Language::Bash => tokei::LanguageType::Bash,
            Language::C => tokei::LanguageType::C,
            Language::CMake => tokei::LanguageType::CMake,
            Language::CSharp => tokei::LanguageType::CSharp,
            Language::Ceylon => tokei::LanguageType::Ceylon,
            Language::Clojure => tokei::LanguageType::Clojure,
            Language::CoffeeScript => tokei::LanguageType::CoffeeScript,
            Language::ColdFusion => tokei::LanguageType::ColdFusion,
            Language::Coq => tokei::LanguageType::Coq,
            Language::Cpp => tokei::LanguageType::Cpp,
            Language::Crystal => tokei::LanguageType::Crystal,
            Language::Css => tokei::LanguageType::Css,
            Language::D => tokei::LanguageType::D,
            Language::Dart => tokei::LanguageType::Dart,
            Language::Dockerfile => tokei::LanguageType::Dockerfile,
            Language::Elisp => tokei::LanguageType::Elisp,
            Language::Elixir => tokei::LanguageType::Elixir,
            Language::Elm => tokei::LanguageType::Elm,
            Language::Emojicode => tokei::LanguageType::Emojicode,
            Language::Erlang => tokei::LanguageType::Erlang,
            Language::FSharp => tokei::LanguageType::FSharp,
            Language::Fish => tokei::LanguageType::Fish,
            Language::Forth => tokei::LanguageType::Forth,
            Language::FortranLegacy => tokei::LanguageType::FortranLegacy,
            Language::FortranModern => tokei::LanguageType::FortranModern,
            Language::GdScript => tokei::LanguageType::GdScript,
            Language::Glsl => tokei::LanguageType::Glsl,
            Language::Go => tokei::LanguageType::Go,
            Language::Graphql => tokei::LanguageType::Graphql,
            Language::Groovy => tokei::LanguageType::Groovy,
            Language::Haskell => tokei::LanguageType::Haskell,
            Language::Haxe => tokei::LanguageType::Haxe,
            Language::Hcl => tokei::LanguageType::Hcl,
            Language::Hlsl => tokei::LanguageType::Hlsl,
            Language::HolyC => tokei::LanguageType::HolyC,
            Language::Html => tokei::LanguageType::Html,
            Language::Idris => tokei::LanguageType::Idris,
            Language::Java => tokei::LanguageType::Java,
            Language::JavaScript => tokei::LanguageType::JavaScript,
            Language::Json => tokei::LanguageType::Json,
            Language::Jsonnet => tokei::LanguageType::Jsonnet,
            Language::Jsx => tokei::LanguageType::Jsx,
            Language::Julia => tokei::LanguageType::Julia,
            Language::Jupyter => tokei::LanguageType::Jupyter,
            Language::Kotlin => tokei::LanguageType::Kotlin,
            Language::LLVM => tokei::LanguageType::LLVM,
            Language::Lisp => tokei::LanguageType::Lisp,
            Language::Lua => tokei::LanguageType::Lua,
            Language::Makefile => tokei::LanguageType::Makefile,
            Language::Markdown => tokei::LanguageType::Markdown,
            Language::Nim => tokei::LanguageType::Nim,
            Language::Nix => tokei::LanguageType::Nix,
            Language::OCaml => tokei::LanguageType::OCaml,
            Language::ObjectiveC => tokei::LanguageType::ObjectiveC,
            Language::Odin => tokei::LanguageType::Odin,
            Language::Org => tokei::LanguageType::Org,
            Language::Oz => tokei::LanguageType::Oz,
            Language::Pascal => tokei::LanguageType::Pascal,
            Language::Perl => tokei::LanguageType::Perl,
            Language::Perl6 => tokei::LanguageType::Perl6,
            Language::Php => tokei::LanguageType::Php,
            Language::PowerShell => tokei::LanguageType::PowerShell,
            Language::Processing => tokei::LanguageType::Processing,
            Language::Prolog => tokei::LanguageType::Prolog,
            Language::Protobuf => tokei::LanguageType::Protobuf,
            Language::PureScript => tokei::LanguageType::PureScript,
            Language::Python => tokei::LanguageType::Python,
            Language::Qml => tokei::LanguageType::Qml,
            Language::R => tokei::LanguageType::R,
            Language::Racket => tokei::LanguageType::Racket,
            Language::Renpy => tokei::LanguageType::Renpy,
            Language::Ruby => tokei::LanguageType::Ruby,
            Language::Rust => tokei::LanguageType::Rust,
            Language::Sass => tokei::LanguageType::Sass,
            Language::Scala => tokei::LanguageType::Scala,
            Language::Scheme => tokei::LanguageType::Scheme,
            Language::Sh => tokei::LanguageType::Sh,
            Language::Solidity => tokei::LanguageType::Solidity,
            Language::Sql => tokei::LanguageType::Sql,
            Language::Svelte => tokei::LanguageType::Svelte,
            Language::Svg => tokei::LanguageType::Svg,
            Language::Swift => tokei::LanguageType::Swift,
            Language::SystemVerilog => tokei::LanguageType::SystemVerilog,
            Language::Tcl => tokei::LanguageType::Tcl,
            Language::Tex => tokei::LanguageType::Tex,
            Language::Toml => tokei::LanguageType::Toml,
            Language::Tsx => tokei::LanguageType::Tsx,
            Language::TypeScript => tokei::LanguageType::TypeScript,
            Language::Vala => tokei::LanguageType::Vala,
            Language::Verilog => tokei::LanguageType::Verilog,
            Language::Vhdl => tokei::LanguageType::Vhdl,
            Language::VimScript => tokei::LanguageType::VimScript,
            Language::VisualBasic => tokei::LanguageType::VisualBasic,
            Language::Vue => tokei::LanguageType::Vue,
            Language::WebAssembly => tokei::LanguageType::WebAssembly,
            Language::Wolfram => tokei::LanguageType::Wolfram,
            Language::XSL => tokei::LanguageType::XSL,
            Language::Xaml => tokei::LanguageType::Xaml,
            Language::Xml => tokei::LanguageType::Xml,
            Language::Yaml => tokei::LanguageType::Yaml,
            Language::Zig => tokei::LanguageType::Zig,
            Language::Zsh => tokei::LanguageType::Zsh,
            
        }
    }
}

impl Language {
    pub fn get_ascii_art(&self) -> &'static str {
        match self {
            Language::ABNF => "{0}          ______
{0}         |      |
{0}         |  /\\  |
{0}>>---+-->| /--\\ |-->+--->>
{0}     |   |______|   |
{0}     |    ______    |
{0}     |   |  __  |   |
{0}     |   | |__) |   |
{0}     +-->| |__) |-->+
{0}     |   |______|   |
{0}     |    ______    |
{0}     |   |      |   |
{0}     |   | |\\ | |   |
{0}     +-->| | \\| |-->+
{0}     |   |______|   |
{0}     |    ______    |
{0}     |   |  ___ |   |
{0}     |   | |___ |   |
{0}     +-->| |    |-->+
{0}         |______|
",
            Language::Abap => "{0}xxxxxxxxxxxxxxxxxxxx
{0}xx{1}###{0}xxx{1}##{0}xx{1}####{0}xxx{1} ##  ####   ##  ####
{0}x{1}#{0}xxxxx{1}#{0}xx{1}#{0}x{1}#{0}xxx{1}#{0}x{1} #  # #   # #  # #   #
{0}xx{1}###{0}xx{1}####{0}x{1}####{0}x{1}  #### ####  #### ####
{0}xxxxx{1}#{0}x{1}#{0}xx{1}#{0}x{1}#{0}xxx{1}   #  # #   # #  # #
{0}x{1}####{0}xx{1}#{0}xx{1}#{0}x{1}#{0}xx{1}    #  # ####  #  # #
{0}xxxxxxxxxxxxxx
",
            Language::Ada => "{0}                              *
{0}                              *
{0}                            * **
{0}   *                        *****
{0}   **                       ******
{0}    **                   ###********
{0}    ***          -******#\'###*********
{0}     *****               #### *********
{0}      ****************************{1}XXX{0}**
{0}     ** ******************{1}XXXX{2}o{1}X{0}*{1}X{2}o{1}XXX{0}*
{0}      **** ***************{1}XXXX{2}ooooo{1}XX{0}*
{0}        *******************{1}XXXX{2}ooooo{1}X
{0}          *******************{1}XXX{2}ooo{1}X
{0}          ************************{1}XX{0}*
{0}             *************    ******
{0}  /| |                           ****
{0} /-|(|(|                     ********
{0}                        ************
{0}Time-tested, safe     *************
{0}and secure            ***********
{0}                         *****
",
            Language::Agda => "{0}   / / /           /  /
{0}  / / /           /  / /
{0} / o o           /    / /
{0}/____           /      /
{0}     |                 |
{0}     |                 |
{0}     ;                 ;
{0}      \\               /
{0}       \'.           .\'
{0}         \'-._____.-\'
",
            Language::Arduino => "{0}   ,=======.    ,=======.
{0}  //       \\\\  //       \\\\
{0} //         \\\\//    #    \\\\
{0} ||   ###    //    ###   ||
{0} \\\\         //\\\\    #    //
{0}  \\\\       //  \\\\       //
{0}   `=======\'    `=======\'
{0}      _   _              _
{0} /\\  |_) | \\ | | | |\\ | / \\
{0}/--\\ | \\ |_/ |_| | | \\| \\_/
",
            Language::Assembly => "{0}     __________________________
{0}    /                          \\
{1}==={0}|  {1}.-.                       {0}|{1}===
{0}   | {1}(   )                      {0}|
{1}==={0}|  {1}\'-\'                       {0}|{1}===
{0}   |                            |
{1}==={0}|     {2} _____  ___ ____       {0}|{1}===
{0}   |     {2}(____ |/___)    \\      {0}|
{1}==={0}|     {2}/ ___ |___ | | | |     {0}|{1}===
{0}   |     {2}\\_____(___/|_|_|_|     {0}|
{1}==={0}|                            |{1}===
{0}   |                            |
{1}==={0}|                       {1}.-.  {0}|{1}===
{0}   |                      {1}(   ) {0}|
{1}==={0}|                       {1}\'-\'  {0}|{1}===
{0}    \\__________________________/
",
            Language::AutoHotKey => "{1} .----------------.
{1}| .--------------. |
{1}| | {0} ____  ____ {1} | |
{1}| | {0}|_   ||   _|{1} | |
{1}| | {0}  | |__| |  {1} | |
{1}| | {0}  |  __  |  {1} | |
{1}| | {0} _| |  | |_ {1} | |
{1}| | {0}|____||____|{1} | |
{1}| |              | |
{1}| \'--------------\' |
{1} \'----------------\'
",
            Language::Bash => "{0}             _._
{0}         _.-\'   \'-._
{0}     _.-\'           \'-._
{0} _.-\'                   \'-._
{0}|                        _,-|
{0}|                    _,-\'+++|
{0}|                _,-\'+++++++|
{0}|             ,-\'+++++++++++|
{0}|             |++++ ++++++++|
{0}|             |+++   +++++++|
{0}|             |++  +++++++++|
{0}|             |++++  +++{1}**{0}++|
{0}|             |++   ++{1}**{0}++++|
{0}\'-,_          |+++ ++++++_,-\'
{0}    \'-,_      |++++++_,-\'
{0}        \'-,_  |++_,-\'
{0}            \'-|-\'
",
            Language::C => "{0}                 ++++++
{0}              ++++++++++++
{0}          ++++++++++++++++++++
{0}       ++++++++++++++++++++++++++
{0}    ++++++++++++++++++++++++++++++++
{0} +++++++++++++{3}************{0}+++++++++++++
{0}+++++++++++{3}******************{0}++++++++{2};;;
{0}+++++++++{3}**********************{0}++{2};;;;;;;
{0}++++++++{3}*********{0}++++++{3}******{2};;;;;;;;;;;
{0}+++++++{3}********{0}++++++++++{3}**{2};;;;;;;;;;;;;
{0}+++++++{3}*******{0}+++++++++{2};;;;;;;;;;;;;;;;;
{0}+++++++{3}******{0}+++++++{2};;;;;;;;;;;;;;;;;;;;
{0}+++++++{3}*******{0}+++{1}:::::{2};;;;;;;;;;;;;;;;;;
{0}+++++++{3}********{1}::::::::::{3}**{2};;;;;;;;;;;;;
{0}++++++++{3}*********{1}::::::{3}******{2};;;;;;;;;;;
{0}++++++{1}:::{3}**********************{1}::{2};;;;;;;
{0}+++{1}::::::::{3}******************{1}::::::::{2};;;
{1} :::::::::::::{3}************{1}:::::::::::::
{1}    ::::::::::::::::::::::::::::::::
{1}       ::::::::::::::::::::::::::
{1}          ::::::::::::::::::::
{1}              ::::::::::::
{1}                 ::::::
",
            Language::CMake => "{0}            ;e{2}`
{0}           ;QD{2}?`
{0}          ;B#R{2}1r`
{0}         ;WRMK{2}S|r`
{0}        :O9KOK{2}S\\\\*`
{0}       :keXPk6{2}Zc7v|`
{0}      :ajyoaZe{3}m{2}JJ{]\\`
{0}     :]z1x}f9{3}@@{2}yujSoc`
{0}    \"7\\/LvU{3}Q@@@{2}XoZemXv`
{0}   ,\\**v{1}oo{3}qMBBB{2}kmXEkU9z`
{0}  ,\\*}{1}Sx\\||?|cFf{2}okqOdHDx`
{0} ,L]{1}jc\\\\\\||?*>rr^^|zo{2}$MN]`
{0}-v{1}7????*>>rrr^^^;;;;;;^\\{2}F^`
",
            Language::CSharp => "{0}                 ++++++
{0}              ++++++++++++
{0}          ++++++++++++++++++++
{0}       ++++++++++++++++++++++++++
{0}    ++++++++++++++++++++++++++++++++
{0} +++++++++++++{3}************{0}+++++++++++++
{0}+++++++++++{3}******************{0}++++++++{2};;;
{0}+++++++++{3}**********************{0}++{2};;;;;;;
{0}++++++++{3}*********{0}++++++{3}******{2};;;;;;;;;;;
{0}+++++++{3}********{0}++++++++++{3}**{2};;;{3}**{2};;;{3}**{2};;;
{0}+++++++{3}*******{0}+++++++++{2};;;;;;{3}*********{2}::
{0}+++++++{3}******{0}+++++++{2};;;;;;;;;;{3}**{2};;;{3}**{2};;;
{0}+++++++{3}*******{0}+++{1}:::::{2};;;;;;;{3}*********{2};;
{0}+++++++{3}********{1}::::::::::{3}**{2};;;{3}**{2};;;{3}**{2};;;
{0}++++++++{3}*********{1}::::::{3}******{2};;;;;;;;;;;
{0}++++++{1}:::{3}**********************{1}::{2};;;;;;;
{0}+++{1}::::::::{3}******************{1}::::::::{2};;;
{1} :::::::::::::{3}************{1}:::::::::::::
{1}    ::::::::::::::::::::::::::::::::
{1}       ::::::::::::::::::::::::::
{1}          ::::::::::::::::::::
{1}              ::::::::::::
{1}                 ::::::
",
            Language::Ceylon => "{1}                                 @@
{1}                                 @@
{3}          @@@@@@@{1}@@@@@@@@@@@@@@   @@
{0}    @@@{3}@@@@@@@@@@{1}@@@@@@ /@@@@@@@@  @@@
{0}  @@@@@@{3}@@@@@@@@@@{1}@@@@ (@@@@ @@@@@  @@{2}@@
{0} @@@@@@@@{3}@@@@@@@@@@@{1}@@@ \\@@@@@@@@@@@@{2}@@@
{0}@@@@@@@@@@@{3}@@@@@@@@@@@{1}@@@@@@@@@@@@@{2}@@@@
{0}|/ @@@@@@@@@@{3}@@@@@@@@@@@@{1}@
{0}   @@@@@@@@@@@@{3}@@@@@@@@@@
{0}   @@@@@@@@@@@@@@{3}@@@@@@@ {4}@@
{0}    @@@@@@@     @@@@@@@ {4}@@@
{0}    @@@@@@ {4}@@    {0}@@@@@ {4}@@@@
{0}     @@@@ {4}@@@    {0}@@@@@ {4}@@@@@
",
            Language::Clojure => "{0}               ,....,
{0}          ,oooooooooooooo,
{0}      ,oooooooooooooooooooooo,
{0}    ,oooooooooooooooooooooooooo,
{0}   ,oooooo::\'        \'\':ooooooooo,
{0}  \'            \'\\\\\\\\\\:   :oooooooo,
{1}  .,,ooo\'  :/:  {0}:\\\\\\\\\\\\\\,  :ooooooo,
{1} :,oooo:  :///:  {0}:\\\\\\\\\\\\\\\\,  :oooooo:
{1}:ooooo:  ://///:, {0}:\\\\\\\\\\\\\\\\,  :ooooo:
{1}\'ooooo: :///////:  {0}:\\\\\\\\\\\\\\,  :ooooo:
{1}\'ooooo: ://////: : {0}:\\\\\\\\\\\\\\,  :ooooo:
{1}\'ooooo:  :////: ::  {0}:\\\\\\\\\\\\,  :ooooo\'
{1}\'oooooo:  ://: ://:  {0}:\\\\\\\\,  :ooooo\'
{1} `oooooo:  :\' :////:  {0}:\\\\. ,;;;::\'
{1}  `oooooo:,   ```````
{1}   `oooooo:::..        .::.,.,::\'
{1}     `oooooooooOOooooOOoooooooo\'
{1}       `ooooooooooooooooooooo\'
{1}         `ooooooooooooooooo\'
{1}             ````````````
",
            Language::CoffeeScript => "{0}           #####    ######
{0}          ###    ###    ###
{0}  /A\\      ######    #####      /A\\
{0}  \\AAAAA\\                   /AAAAA/
{0}       \\AAAAAAAAAAAAAAAAAAAAA/
{0}  \\AA\\                         /AA/
{0}   |\\AAAAAAAAAAAAAAAAAAAAAAAAAAA/|
{0}  /\\\\llAAAAAAAAAAAAAAAAAAAAAAAll//
{0} /#A\\\\llAAAAAAAAAAAAAAAAAAAAAll//
{0}|#A   \\\\llAAAAAAAAAAAAAAAAAAll//
{0} \\#A    \\\\llAAAAAAAAAAAAAAll//
{0}   \\#A   \\\\llAAAAAAAAAAAAll//
{0}     \\#A>  ||lAAAAAAAAAAl||
{0}            \\;AAAAAAAAAA;/
",
            Language::ColdFusion => "{0}CfCfCfCfCfCfCfCfCfCfCfCfCfCfCfCfCfCf
{0}Cf{1}@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@{0}Cf
{0}Cf{1}@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@{0}Cf
{0}Cf{1}@@@@@@@@@@@@@@@@@@@@@@{0}CfCfCfCf{1}@@{0}Cf
{0}Cf{1}@@@@@{0}CfCfCfCfCf{1}@@@@{0}CfCfCfCfCf{1}@@@{0}Cf
{0}Cf{1}@@@@{0}CfCfCfCfCf{1}@@@@{0}CfCf{1}@@@@@@@@@@{0}Cf
{0}Cf{1}@@@{0}CfCf{1}@@@@@@@@@@{0}CfCf{1}@@@@@@@@@@@{0}Cf
{0}Cf{1}@@{0}CfCf{1}@@@@@@@@{0}CfCfCfCfCfCf{1}@@@@@@{0}Cf
{0}Cf{1}@@{0}CfCf{1}@@@@@@@@@@@{0}CfCf{1}@@@@@@@@@@@{0}Cf
{0}Cf{1}@@{0}CfCf{1}@@@@@@@@@@@{0}CfCf{1}@@@@@@@@@@@{0}Cf
{0}Cf{1}@@@{0}CfCf{1}@@@@@@@@@@{0}CfCf{1}@@@@@@@@@@@{0}Cf
{0}Cf{1}@@@@{0}CfCfCfCfCf{1}@@@{0}CfCf{1}@@@@@@@@@@@{0}Cf
{0}Cf{1}@@@@@{0}CfCfCfCfCf{1}@@{0}CfCf{1}@@@@@@@@@@@{0}Cf
{0}Cf{1}@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@{0}Cf
{0}Cf{1}@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@{0}Cf
{0}CfCfCfCfCfCfCfCfCfCfCfCfCfCfCfCfCfCf
",
            Language::Coq => "{0}   ::::::::
{0} :::::::::::
{0} :::::::::::
{0} :::::{1}___{0}:::
{1}   ______ {0}:
{1}     ____   _________
{1}      ___  ___________
{1}      ___ ____________
{1}     _________________
{1}   ___________________
{1}______________ ______
{1}   ___________ ___
{1}      ______
{1}       ____
{1}     ______
{1}    ________
{1}    ________
",
            Language::Cpp => "{0}                 ++++++
{0}              ++++++++++++
{0}          ++++++++++++++++++++
{0}       ++++++++++++++++++++++++++
{0}    ++++++++++++++++++++++++++++++++
{0} +++++++++++++{3}************{0}+++++++++++++
{0}+++++++++++{3}******************{0}++++++++{2};;;
{0}+++++++++{3}**********************{0}++{2};;;;;;;
{0}++++++++{3}*********{0}++++++{3}******{2};;;;;;;;;;;
{0}+++++++{3}********{0}++++++++++{3}**{2};;;;;;;;;;;;;
{0}+++++++{3}*******{0}+++++++++{2};;;;;;{3}**{2};;;;{3}**{2};;;
{0}+++++++{3}******{0}+++++++{2};;;;;;;;{3}****{2};;{3}****{2};;
{0}+++++++{3}*******{0}+++{1}:::::{2};;;;;;;{3}**{2};;;;{3}**{2};;;
{0}+++++++{3}********{1}::::::::::{3}**{2};;;;;;;;;;;;;
{0}++++++++{3}*********{1}::::::{3}******{2};;;;;;;;;;;
{0}++++++{1}:::{3}**********************{1}::{2};;;;;;;
{0}+++{1}::::::::{3}******************{1}::::::::{2};;;
{1} :::::::::::::{3}************{1}:::::::::::::
{1}    ::::::::::::::::::::::::::::::::
{1}       ::::::::::::::::::::::::::
{1}          ::::::::::::::::::::
{1}              ::::::::::::
{1}                 ::::::
",
            Language::Crystal => "{0}            ,loc;\'..
{0}          ,xNMMMWNXK0kdl,..
{0}        ,xNMMMMMMMMMMMMMKOxoc;.
{0}      ,xNMMMMMMMMMMMMMMMMMMMMWX:
{0}    ,xNMMMMMMMMMMWNNWMMMMMMMMMMk.
{0}  ,xNMMMMMWX0kdlc;:lOMMMMMMMMMMNc
{0},xXK{1}..mmmMMMMMMMM\'{0}0MMMMMMMMMMMMMO.
{0}0o;{1}MMMMMMMMMMMMMm{0}.MMMMMMMMMMMMMMWl
{0}0O:.{1}MMMMMMMMMMMM\'{0}cMMMMMMMMMMMMMMM0\'
{0}oWWO:.{1}MMMMMMMMMm{0}.OMMMMMMMMMMMMMMMWo
{0}\'0MMWO:.{1}MMMMMMM\'{0}lWMMMMMMMMMMMMMMMMK,
{0} lWMMMWO:.{1}MMMMm{0}\'0MMMMMMMMMMMMMMMMMWd
{0} .OMMMMMW0c.{1}MM\'{0}oWMMMMMMMMMMMMMMMMMWk.
{0}  cNMMMMMMW0c{1}\'{0},KMMMMMMMMMMMMMMMMW0c.
{0}  .kMMMMMMMMW00WMMMMMMMMMMMMMMW0c.
{0}   cNMMMMMMMMMMMMMMMMMMMMMMMW0c.
{0}   .xWMMMMMMMMMMMMMMMMMMMMW0:.
{0}    .\';coxOKNWMMMMMMMMMMWO:.
{0}           ..,:ldk0KXWMM:.
{0}               ...\';c:
",
            Language::Css => "{1}        ####    ####    ####
{1}       ##  ##  ##      ##
{1}       ##       ####    ####
{1}       ##  ##      ##      ##
{1}        ####    ####    ####
{0}(((((((((((((((((((((((((((((((((((
{0}(((((((((((((((((/////////////(((((
{0}(((((((((((((((((/////////////(((((
{0}(((((((                    ///(((((
{0} ((((((                    ///((((
{0} ((((((((((((((((        /////((((
{0} (((((((((((        //////////((((
{0} (((((((                   ///((((
{0}  ((((((                   ///(((
{0}  (((((((((((((((//////    ///(((
{0}  (((((((    ((((//////    ///(((
{0}  (((((((                  ///(((
{0}   (((((((               /////((
{0}   ((((((((((((((/////////////((
{0}   ((((((((((((((//////(((((((((
{0}          (((((((((((((((
",
            Language::D => "{0}                                    DDD
{0}DDDDDDDDDDDDDDDDDDDDDD             DDDDD
{0}DDDDDDDDDDDDDDDDDDDDDDDD            DDD
{0}DDDDDDDDDDDDDDDDDDDDDDDDDD     DDDDD
{0}DDDDDD               DDDDDDD DDDDDDDDD
{0}DDDDDD                DDDDDDDDDDDDDDDDD
{0}DDDDDD                 DDDDDDDDDDDDDDDD
{0}DDDDDD                 DDDDDDDDDDDDDD
{0}DDDDDD                 DDDDDDDDDDD
{0}DDDDDD                 DDDDDDD
{0}DDDDDD                DDDDDDD
{0}DDDDDD               DDDDDDD
{0}DDDDDDDDDDDDDDDDDDDDDDDDDDD
{0}DDDDDDDDDDDDDDDDDDDDDDDDD
{0}DDDDDDDDDDDDDDDDDDDDDD
",
            Language::Dart => "{0}#
{0} ##
{0}  ###
{0}   ######              ###
{0}    #########        #######
{0}      ###########  ######{2}O{0}##{2}========-
{0}       #####################
{0}         ##################
{0}      ###############{1}+++++
{0}###################{1}+++++++
{0}        ##########{1}+++++++
{0}               ##{1}+++++++
{0}               ###{1}+++
{0}               #####
{0}               #######
{0}               #########
{0}                #######
{0}                 #####
",
            Language::Dockerfile => "{2}                  ##   {0}      .
{2}            ## ## ##   {0}     ==
{2}         ## ## ## ## ##{0}    ===
{0}     /\"\"\"\"\"\"\"\"\"\"\"\"\"\"\"\"\"\\___/ ===
{1}~~~ {0}{{1}~~ ~~~~ ~~~ ~~~~ ~~~ ~ {0}/  ===-{1} ~~~
{0}     \\{1}______ o{0}           __/
{1}       \\    \\ {0}        __/
{1}        \\____\\{0}_______/
",
            Language::Elisp => "{0}         \':r\\iv7i|r:\'
{0}      :LFaZZZaaaoooo2t\\:
{0}    ^]aZZZZaaw9DN{1}Q@Q{0}gojjv;
{0}  ,vaZZZaX69KOHRW#{1}@@@{0}Ouuuu/,
{0} _[ZZaaa{1}Q@@@@QBNMRD{0}dEuuufFFl,
{0}.7aaaooo{1}wB@@#{0}h2jjuuuufFF]]]]|-
{0}:yooooSSS2S${1}gQ@Q{0}8hjfFF]]]][tz\"
{0};oooSS2ed#{1}Q@@@@@Q{0}N{0}Do]]][[ttt[:
{0}:uSS2mQ{1}@@@@Q{0}deuF]]]][[ttt[[[z~
{0}-/yjjO{1}@@@@Q{0}uFF]]][[tttt[[]]]?`
{0} ,vuuue&{1}Q@@@QQ#NNggg{0}&D9u[]i\'
{0}  \'/ffFF]]jek99OR{1}#Q@@Q{0}Hj]]|\'
{0}   `;c]]][uaXUKO$wo]]]]L:`
{0}     `,>i1tt[[]]]]ti>,`
{0}        `.~;^>??>^;,-`
",
            Language::Elixir => "{0}            x
{0}           WNX
{0}          Odc:xN
{0}        0ddko,oX
{0}       kokNWOllOW
{0}     KdoKWMMNKxl0W
{0}    0odXMMMMMMNxoON
{0}   0lxNMMMMMMMMW0dd0N
{0}  0oxNMMMMMMMMMMMNOodKW
{0}  odXMMMMMMMMMMMMMMXxokN
{0} xl0MMMMMMMMMMMMMMMMW0odX
{0}xoxWMMMMMMMMMMMMMMMMMMKodN
{0}0lOMMMMMMMMMMMMMMMMMMMWOlO
{0}OlOMWKXMMMMMMMMMMMMMMMMKlxW
{0}KlxWXodNMMMMMMMMMMMMMMM0lkW
{0}xxoKWOlkNMMMMMMMMMMMMMWkl0
{0} XooKN0ddkKNWWWMMMMMMWOlkW
{0}  XxokXN0kxxkkKMMMMN0doON
{0}   WKxdxk0KKKKXK0OxddkXW
{0}     WNKOxxxxxxxxkOXW
{0}         WWWWWWW
",
            Language::Elm => "{0}   {1}ElmElmElmElm   {3}ElmElmElmElmElm
{0}El   {1}mElmElmElmEl   {3}mElmElmElmElm
{0}Elm   {1}ElmElmElmElmE   {3}lmElmElmElm
{0}ElmEl   {1}mElmElmElmElm   {3}ElmElmElm
{0}ElmElmE                   {3}mElmElm
{0}ElmElmElm   {2}ElmElmElmEl     {3}lmElm
{0}ElmElmElmEl   {2}mElmElm   {1}Elm   {3}Elm
{0}ElmElmElmElmE   {2}lmE   {1}lmElmEl   {3}m
{0}ElmElmElmElmElm     {1}mElmElmElmE
{0}ElmElmElmElmElmE    {1}mElmElmElm
{0}ElmElmElmElmEl   {3}mE   {1}lmElmE   {2}lm
{0}ElmElmElmElm   {3}ElmElm   {1}El   {2}mElm
{0}ElmElmElmE   {3}lmElmElmEl    {2}ElmElm
{0}ElmElmEl   {3}mElmElmElmElmE   {2}lmElm
{0}ElmElm   {3}ElmElmElmElmElmElm   {2}Elm
{0}ElmE   {3}lmElmElmElmElmElmElmEl   {2}m
{0}El   {3}mElmElmElmElmElmElmElmElmE
{0}   {3}ElmElmElmElmElmElmElmElmElmElm
",
            Language::Emojicode => "{0}~~
{0} ~~
{0}  ~~
{0}   ~~{2}           \'\'\'\'\'\'\'\'
{0}    ~~~{2}       \'\'\'\'\'\'\'\'\'\'\'\'
{0}     {1}````````{2}\'\'\'\'\'\'\'\'\'\'\'\'\'\'
{1}    `````````{2}\'\'\'\'\'\'\'\'\'\'\'\'\'\'
{1}   `````````{2}\'\'\'\'\'\'\'\'\'\'\'\'\'{3}~~~~~~~-
{1}   `````````{2}\'\'\'\'\'\'\'\'\'\'\'{3}~~~~~~~~~~~
{1}   ``````````{2}\'\'{1}````````{3}~~~~~~~~~~~~
{1}   ``````````````````````{3}~~~~~~~~~~~
{1}   ```````````````````````{3}~~~~~~~~~~
{1}    ``{3}~~~~~{1}```````````````{3}~~~~~~~~~~
{3}   -~~~~~~~{1}```````````````{3}~~~~~~~~~
{3}  ~~~~~~~~~{1}```````````````````````
{3}  ~~~~~~~~~~{1}````````````````````````
{3} ~~~~~~~~~~~~{1}`````````````````````````
{3}  ~~~~~~~~~~~~~~{1}``````{2}````````````````
{3}  ~~~~~~~~~~~~~~{2}\'\'\'\'\'\'\'{1}```````````````
{3}   ~~~~~~~~~~~~{2}\'\'\'\'\'\'\'\'{1}```````````````
{3}     ~~~~~~~~{2}\'\'\'\'\'\'\'\'\'\'\'{1}``````````````
{2}              {2}\'\'\'\'\'\'\'\'\'\'\'{1}````````````
{2}                {2}\'\'\'\'\'\'\'\'   {1}````````
",
            Language::Erlang => "{0}   EEEEEEEEEEEEE      EEEEEEEEEEEE
{0}  EEEEEEEEEEEE         EEEEEEEEEEEE
{0} EEEEEEEEEEEE           EEEEEEEEEEE
{0} EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
{0}EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
{0}EEEEEEEEEEEEE
{0}EEEEEEEEEEEEE
{0}EEEEEEEEEEEEE
{0} EEEEEEEEEEEEE                 E
{0} EEEEEEEEEEEEE                EEEEE
{0}  EEEEEEEEEEEEE             EEEEEEEEE
{0}   EEEEEEEEEEEEEE         EEEEEEEEEE
",
            Language::FSharp => "{0}                 /  {1}((
{0}               ///  {1}((((
{0}             /////  {1}((((((
{0}           ///////  {1}((((((((
{0}         /////////  {1}((((((((((
{0}       //////////   {1}  ((((((((((
{0}     //////////  /  {1}    ((((((((((
{0}   //////////  ///  {1}      ((((((((((
{0} //////////  /////  {1}        ((((((((((
{0}/////////   //////  {1}         ((((((((((
{0}  /////////   ////  {1}       ((((((((((
{0}    /////////   //  {1}     ((((((((((
{0}      /////////     {1}   ((((((((((
{0}        /////////   {1} ((((((((((
{0}          ////////  {1}(((((((((
{0}            //////  {1}(((((((
{0}              ////  {1}(((((
{0}                //  {1}(((
",
            Language::Fish => "{0}                 ___
{0}  ___======____=-{1}-{0}-=)
{0}/T            \\_{1}--={0}==)
{0}[ \\ ({1}0{0})   \\~    \\_{1}-={0}=)
{0} \\      / )J~~    \\{1}-={0})
{0}  \\\\___/  )JJ~{1}~~{0}   \\)
{0}   \\_____/JJJ~~{1}~~{0}    \\
{0}   / \\  {1}, \\{0}J~~~{1}~~{0}     \\
{0}  (-{1}\\){0}\\=|{1}\\\\\\{0}~~{1}~~{0}       L_{1}_
{0}  (\\\\)  ({1}\\{0}\\\\)_           {1}\\==__
{0}   \\V    \\\\\\) ===_____   {1}\\\\\\\\{0}\\\\
{0}          \\V)     \\_) \\\\{1}\\\\JJ\\{0}J\\)
{0}                      /J{1}\\J{0}T\\JJJJ)
{0}                      (JJJ| \\UUU)
{0}                       (UU)
",
            Language::Forth => "{0}::::::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::::::
{0}::::::          ::::::::          ::::::
{0}::::::          ::::::::          ::::::
{0}::::::          ::::::::          ::::::
{0}::::::          ::::::::          ::::::
{0}::::::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::::::
{0}::::::          ::::::::          ::::::
{0}::::::          ::::::::          ::::::
{0}::::::          ::::::::          ::::::
{0}::::::          ::::::::         :::::::
{0}::::::::::::::::::::::::::     :::::::::
{0}::::::::::::::::::::::::     :::::::::::
{0}::::::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::::::
",
            Language::FortranLegacy => "{4}    _ {1}__ __
{4}  _|_ {1} /  /
{0}  o{4}|{1}  /  /
{0}      /\\
{0}     /  \\
{0}    |    |
{0}    |{2}NASA{0}|
{0}    |    |
{0}    |    |
{0}    |    |
{0}   \'      \'
{0}   |      |
{0}   |      |
{0}   |______|
{3}   /-`\'-`.\\
{3}  ; / . \\\'\\.
{3} \'/\'\'( .\'\\.\'\'
{3}\'.\'.;.;\' ;\'.;\'
",
            Language::FortranModern => "{4}    _{1} _  _
{4}  _|_{1}(_|/ \\
{0}  o{4}| {1} _|\\_/
{0}      /\\
{0}     /  \\
{0}    |    |
{0}    |{2}NASA{0}|
{0}    |    |
{0}    |    |
{0}    |    |
{0}   \'      \'
{0}   |      |
{0}   |      |
{0}   |______|
{3}   /-`\'-`.\\
{3}  ; / . \\\'\\.
{3} \'/\'\'( .\'\\.\'\'
{3}\'.\'.;.;\' ;\'.;\'
",
            Language::GdScript => "{0}         _.aMb      dMe._
{0}        \'H8888b,  ,d8888H\'
{0}   .   .:88888d8888888888:.   .
{0} .d8b.dM888888888888888888Mb.d8b.
{0}d88888888888888888888888888888888b
{0}\'V888888888888888888888888888888V\'
{0} 88888888888888888888888888888888
{0} 8888P\' {1}__{0} \"V88888888V\" {1}__{0} \'V8888
{0} 8888\" {1}dMMb {0}\'888{1}\'\'{0}888\' {1}d88b {0}\"8888
{0} 8888b {1}:HH: {0}/888{1}  {0}888\\ {1}:HH: {0}d8888
{0} 8888be._.ad8888{1}..{0}8888be._.ad8888
{0} WW8888888888888888888888888888WW
{0} {1}#######{0}YW88/{1}########{0}\\88WY{1}#######
{0} MWbzxe{1}##{0}8MW;{1}##{0}8888{1}##{0};8MW{1}##{0}aezdWM
{0} \'Y8888b.{1}#####{0}/8888\\{1}#####{0}.d8888Y\'
{0}  \"V8888888888888888888888888V\"
{0}   \'^YV8888888888888888888VP^\'
{0}      \'\"^^VY888888888VY^^\'
",
            Language::Glsl => "{0}         ,,@@@@@@@@@@@@@@@@@..
{0}       ,@@@@@@@@@@@@@@@@@@@@@@@.
{0}     ,@@@@@@@@@@@@@@@@@@@@@@@@@@@.
{0}   ,@@@@@@@@\'              `@@@@@@@.
{0} ,@@@@@@@@\'                    `@@@@.
{0},@@@@@@@\'                         `@@.
{0}@@@@@@@\' {1}_____  _        _____  _   {0}`@
{0}@@@@@@  {1}/:::::||:|      /:::::||:|
{0}@@@@@@ {1}|:|  __ |:|     |:(___  |:|
{0}@@@@@@ {1}|:| |::||:|      \\::::\\ |:|
{0}@@@@@@ {1}|:|__|:||:|____  ____):||:|____
{0}@@@@@@  {1}\\:::::||::::::||:::::/ |::::::|
{0}@@@@@@@.                            ,@
{0}`@@@@@@@.                         ,@@\'
{0} `@@@@@@@@.                    ,@@@@\'
{0}   `@@@@@@@@.              ,@@@@@@@\'
{0}     `@@@@@@@@@@@@@@@@@@@@@@@@@@@\'
{0}       `@@@@@@@@@@@@@@@@@@@@@@@\'
{0}         ``@@@@@@@@@@@@@@@@@\'\'
",
            Language::Go => "{0}           --==============--
{0}  .-==-.===oooo=oooooo=ooooo===--===-
{0} .==  =o={1}oGGGGGG{0}o=oo=o{1}GGGGGGG{0}G=o=  oo-
{0} -o= oo={1}G .=GGGGG{0}o=o={1}= .=GGGGG{0}=ooo o=-
{0}  .-=oo={1}o==oGGGGG{0}=oo={1}oooGGGGGo{0}=oooo.
{0}   -ooooo{1}=oooooo{0}={2}.   .{0}={1}=ooo=={0}oooooo-
{0}   -ooooooooooo{2}====_===={0}ooooooooooo=
{0}   -oooooooooooo{2}=={1}#{0}.{1}#{2}=={0}ooooooooooooo
{0}   -ooooooooooooo={1}#{0}.{1}#{0}=oooooooooooooo
{0}   .oooooooooooooooooooooooooooooooo.
{0}    oooooooooooooooooooooooooooooooo.
{2}  ..{0}oooooooooooooooooooooooooooooooo{2}..
{2}-=o-{0}=ooooooooooooooooooooooooooooooo{2}-oo.
{2}.=- {0}oooooooooooooooooooooooooooooooo{2}-.-
{0}   .oooooooooooooooooooooooooooooooo-
{0}   -oooooooooooooooooooooooooooooooo-
{0}   -oooooooooooooooooooooooooooooooo-
{0}   -oooooooooooooooooooooooooooooooo-
{0}   .oooooooooooooooooooooooooooooooo
{0}    =oooooooooooooooooooooooooooooo-
{0}    .=oooooooooooooooooooooooooooo-
{0}      -=oooooooooooooooooooooooo=.
{2}     =oo{0}====oooooooooooooooo==-{2}oo=-
{2}    .-==-    {0}.--=======---     {2}.==-
",
            Language::Graphql => "{0}                 {}{}{}
{0}                {}{}{}{}
{0}                {}{}{}{}
{0}            {}   {}{}{}   {}
{0} {}{}{}  {}    {}      {}    {}  {}{}{}
{0}{}{}{}{}      {}        {}      {}{}{}{}
{0}{}{}{}{}     {}          {}     {}{}{}{}
{0} {}{}{}     {}            {}     {}{}{}
{0}   {}      {}              {}      {}
{0}   {}     {}                {}     {}
{0}   {}    {}                  {}    {}
{0}   {}   {}                    {}   {}
{0}   {}  {}                      {}  {}
{0} {}{}{}                          {}{}{}
{0}{}{}{}{}{}{}{}{}{}{}{}{}{}{}{}{}{}{}{}{}
{0}{}{}{}{}                        {}{}{}{}
{0} {}{}{}  {}                  {}  {}{}{}
{0}            {}   {}{}{}   {}
{0}                {}{}{}{}
{0}                {}{}{}{}
{0}                 {}{}{}
",
            Language::Groovy => "{0}                   *
{0}                  ***
{0}                 *****
{0}                *******
{0}               *********
{0}              ***********
{0}             *************
{0}*****************{1}@@@@@{0}*****************
{0}  *************{1}@{0}******{1}@{0}**************
{0}   ***********{1}@{0}**{1}@@{0}***{1}@{0}*************
{0}    *********{1}@{0}***{1}@@{0}**{1}@{0}**{1}@{0}**********
{0}      *******{1}@{0}****{1}@@{0}***{1}@@@{0}*******
{0}       *******{1}@{0}******{1}@@{0}**{1}@@{0}*****
{0}        *******{1}@@@@@@{0}**{1}@@@@{0}****
{0}         ************{1}@@@@@@{0}***
{0}         ******{1}@@@@@@@@@@@{0}****
{0}        ********{1}@@@@@@@@{0}*******
{0}       **********{1}@@{0}*************
{0}      ***************************
{0}     ***********       ***********
{0}    *********             *********
{0}   *****                       *****
{0}  *                                 *
",
            Language::Haskell => "{0}yyyyyy{1} xxxxxx
{0} yyyyyy{1} xxxxxx
{0}  yyyyyy{1} xxxxxx
{0}   yyyyyy{1} xxxxxx
{0}    yyyyyy{1} xxxxxx{2} yyyyyyyyyy
{0}     yyyyyy{1} xxxxxx{2} yyyyyyyyy
{0}      yyyyyy{1} xxxxxx
{0}     yyyyyy{1} xxxxxxxx{2} yyyyyyy
{0}    yyyyyy{1} xxxxxxxxxx{2} yyyyyy
{0}   yyyyyy{1} xxxxxxxxxxxx
{0}  yyyyyy{1} xxxxxx  xxxxxx
{0} yyyyyy{1} xxxxxx    xxxxxx
{0}yyyyyy{1} xxxxxx      xxxxxx
",
            Language::Haxe => "{0}#############              {2}@@@@@@@@@@@@@
{0}#################      {2}@@@@@@@@@@@@@@@@@
{0}###################{1}XX{2}@@@@@@@@@@@@@@@@@@@
{0}##################{1}XXXX{2}@@@@@@@@@@@@@@@@@@
{0}################{1}XXXXXXXX{2}@@@@@@@@@@@@@@@@
{0}##############{1}XXXXXXXXXXXX{2}@@@@@@@@@@@@@@
{0} ###########{1}XXXXXXXXXXXXXXXX{2}@@@@@@@@@@@
{0}  ########{1}XXXXXXXXXXXXXXXXXXXX{2}@@@@@@@@
{0}   #####{1}XXXXXXXXXXXXXXXXXXXXXXXX{2}@@@@@
{0}    ##{1}XXXXXXXXXXXXXXXXXXXXXXXXXXXX{2}@@
{0}    ##{1}XXXXXXXXXXXXXXXXXXXXXXXXXXXX{2}@@
{0}   #####{1}XXXXXXXXXXXXXXXXXXXXXXXX{2}@@@@@
{0}  ########{1}XXXXXXXXXXXXXXXXXXXX{2}@@@@@@@@
{0} ###########{1}XXXXXXXXXXXXXXXX{2}@@@@@@@@@@@
{0}##############{1}XXXXXXXXXXXX{2}@@@@@@@@@@@@@@
{0}################{1}XXXXXXXX{2}@@@@@@@@@@@@@@@@
{0}##################{1}XXXX{2}@@@@@@@@@@@@@@@@@@
{0}###################{1}XX{2}@@@@@@@@@@@@@@@@@@@
{0}#################      {2}@@@@@@@@@@@@@@@@@
{0}#############              {2}@@@@@@@@@@@@@
",
            Language::Hcl => "{0}::
{0}::::
{0}::::::
{0}::::::::
{0}::::::::::
{0}:::::::::: ::        {1}         ..
{0}  :::::::: ::::      {1}       ....
{0}    :::::: ::::::    {1}     ......
{0}      :::: ::::::::  {1}   ........
{0}        :: ::::::::::{1} ..........
{0}           ::::::::::{1} ..........
{0}             ::::::::{1} ........
{0}           ::  ::::::{1} ......
{0}           ::::  ::::{1} ....
{0}           ::::::  ::{1} ..
{0}           ::::::::
{0}           ::::::::::
{0}           ::::::::::
{0}             ::::::::
{0}               ::::::
{0}                 ::::
{0}                   ::
",
            Language::Hlsl => "{0}████████████████  {1}████████████████
{0}█████  ██  █████  {1}█████  █████████
{0}█████  ██  █████  {1}█████  █████████
{0}█████      █████  {1}█████  █████████
{0}█████  ██  █████  {1}█████  █████████
{0}█████  ██  █████  {1}█████      █████
{0}████████████████  {1}████████████████

{2}████████████████  {3}████████████████
{2}█████      █████  {3}█████  █████████
{2}█████  █████████  {3}█████  █████████
{2}█████      █████  {3}█████  █████████
{2}█████████  █████  {3}█████  █████████
{2}█████      █████  {3}█████      █████
{2}████████████████  {3}████████████████
",
            Language::HolyC => "{0}             ========
{0}         ====        ====
{0}      ====              ====
{0}    ===                   ===
{0}   ===                     ===
{0}  ==           {1}***           {0}==
{0}  ==        {1}*********        {0}==
{0}   =    {1}*****************    {0}=
{1}    ********{0}*********{1}********
{1} ********{0}**{2}***********{0}**{1}********
{1}*******{0}*{2}******{0}*****{2}*****{0}*{1}********
{1}******{0}*{2}*****{0}**{1}*****{0}**{2}***{0}**{1}*******
{1}*****{0}*{2}*****{0}*{1}*********{0}***{1}*********
{1}*****{0}*{2}****{0}*{1}**********************
{1}*****{0}*{2}****{0}*{1}**********************
{1}*****{0}*{2}****{0}*{1}**********************
{1}*****{0}*{2}*****{0}*{1}*********{0}***{1}*********
{1}******{0}*{2}*****{0}**{1}*****{0}**{2}***{0}**{1}*******
{1}*******{0}*{2}******{0}*****{2}*****{0}*{1}********
{1} ********{0}**{2}***********{0}**{1}********
{1}     *******{0}*********{1}*******
{1}        *****************
{1}            *********
{1}               ***
",
            Language::Html => "{1}  ##  ##  ######  ##   ##  ##
{1}  ##  ##    ##    ### ###  ##
{1}  ######    ##    ## # ##  ##
{1}  ##  ##    ##    ##   ##  ##
{1}  ##  ##    ##    ##   ##  ######
{0}(((((((((((((((((((((((((((((((((((
{0}(((((((((((((((((/////////////(((((
{0}(((((((((((((((((/////////////(((((
{0}(((((((                     //(((((
{0} ((((((                     //((((
{0} ((((((    ((((((/////////////((((
{0} ((((((     (((((/////////////((((
{0} ((((((                    ///((((
{0}  (((((                    ///(((
{0}  (((((((((((((((//////    ///(((
{0}  ((((((    (((((/////     ///(((
{0}  ((((((                   ///(((
{0}   (((((((               /////((
{0}   ((((((((((((((/////////////((
{0}   ((((((((((((((//////(((((((((
{0}          (((((((((((((((
",
            Language::Idris => "{0}       %
{0}          %
{0}   %&&&     %%
{0}        %%    %&
{0}&%%%&     %    %%
{0}     %%        %%
{0}       %       %%
{0} %%%          %%&
{0}   %%       %%%
{0}    %     &%%%
{0}         %%%&
{0}       &%%%
{0}      %%%%
{0}      %%%
{0}     %%%
{0}     %%%
{0}     &%%
{0}      %%%
",
            Language::Java => "{0}                  |
{0}                 ||
{0}               |||
{0}             ||||    ||
{0}           ||||| ||||
{0}          ||||  |||
{0}         ||||  |||
{0}         |||    |||
{0}          |||    |||
{0}            ||    ||
{0}              |   |
{1}   ####               #    ##
{1}    ################       ##
{1}       #                   ##
{1}      ################   ###
{1}
{1}       ##############
{1}####      #######          #
{1}#####                   ####
{1}   #####################      #
{1}                          ###
{1}          ###############
",
            Language::JavaScript => "{0}JSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJS
{0}JSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJS
{0}JSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJS
{0}JSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJS
{0}JSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJS
{0}JSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJS
{0}JSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJS
{0}JSJSJSJSJSJSJSJSJ    SJSJS      JSJSJS
{0}JSJSJSJSJSJSJSJSJ    SJS          JSJS
{0}JSJSJSJSJSJSJSJSJ    SJS     JSJSJSJSJ
{0}JSJSJSJSJSJSJSJSJ    SJSJ     SJSJSJSJ
{0}JSJSJSJSJSJSJSJSJ    SJSJSJ     SJSJSJ
{0}JSJSJSJSJSJSJSJSJ    SJSJSJSJ     JSJS
{0}JSJSJSJSJSJSJSJSJ    SJSJSJSJS     JSJ
{0}JSJSJSJSJS     JS    JSJS          JSJ
{0}JSJSJSJSJSJ          SJSJSJ      SJSJS
{0}JSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJS
{0}JSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJSJS
",
            Language::Json => "{0}           `:+osyyyso+/:`
{0}        :smNNNmmmddddhhhmds:
{0}     .oNNNNNmmmddddhhhyyyym{1}MNs.
{0}    oNNNNNmmmddddhhhyyyysssh{1}MMMs`
{0}  .dNNNNmmmddmmmdyyyyysssoooh{1}MMMm.
{0} `mNNNmmmmm{1}NMMMy-{0}  .+ssoooo++N{1}MMMN.
{0} yNNmmmdm{1}MMMMN-  {0}    .ooo+++/d{1}MMMMd
{0}-Nmmmddm{1}MMMMM:   {0}     .+++///y{1}MMMMM-
{0}+mmdddd{1}MMMMMm    {0}      /////:y{1}MMMMM+
{0}+ddddhd{1}MMMMMm    {0}      ///:::m{1}MMMMM+
{0}-ddhhhd{1}MMMMMM-   {0}     `/::::y{1}MMMMMM-
{0} shhyyh{1}MMMMMMm-  {0}    `:::::h{1}MMMMMMh
{0} .yyyyyN{1}MMMMMMMs.{0}  `-:::/y{1}NMMMMMMm`
{0}  .osssh{1}MMMMMMMMMmhyyydNMMMMMMMMd.
{0}    :oood{1}MMMMMMMMMMMMMMMMMMMMMNo
{0}     `:++yN{1}MMMMMMMMMMMMMMMMMNs.
{0}        .-/ym{1}MMMMMMMMMMMMmy:
{0}            `-/oyhhhys+:`
",
            Language::Jsonnet => "{0}        .       .
{0}       /{1}:{0}\\     /{1}:{0}\\
{0}      /{1}:::{0}\\   /{1}:::{0}\\
{0}     /{1}:::::{0}\\ /{1}:::::{0}\\
{0}   /|\\{1}:::::{0}/|\\{1}:::::{0}/|
{0}  /{1}:{0}|#\\{1}:::{0}/{1}.{0}|#\\{1}:::{0}/{1}.{0}|
{0} /{1}::{0}|##\\{1}:{0}/{1}..{0}|##\\{1}:{0}/{1}..{0}|
{0}|\\{1}::{0}|###|{1}...{0}|###|{1}...{0}|
{0}|#\\{1}:{0}|###|{1}...{0}|###|{1}...{0}|
{0}|##\\|###|{1}...{0}|###|{1}...{0}|
{0}|#######|{1}..{0}/{1}:{0}\\##|{1}..{0}/
{0}|#######|{1}.{0}/{1}:::{0}\\#|{1}.{0}/
{0}|#######|/{1}:::::{0}\\|/
{0} \\#######\\{1}:::::{0}/|\\
{0}  \\#######\\{1}:::{0}/{1}.{0}|{1}:{0}\\
{0}   \\#######\\{1}:{0}/{1}..{0}|{1}::{0}\\
{0}    |#######|{1}...{0}|{1}::{0}/|
{0}    |#######|{1}...{0}|{1}:{0}/{1}.{0}|
{0}    |#######|{1}...{0}|/{1}..{0}|
{0}    |###|\\##|{1}..{0}/|{1}...{0}|
{0}    |###|{1}.{0}\\#|{1}.{0}/#|{1}...{0}|
{0}    |###|{1}..{0}\\|/##|{1}...{0}|
{0}     \\##|{1}..{0}/ \\##|{1}..{0}/
{0}      \\#|{1}.{0}/   \\#|{1}.{0}/
{0}       \\|/     \\|/
",
            Language::Jsx => "{0}JSXJSXJSXJSXJSXJSXJSXJSXJSXJSXJSXJSX{1}JSX
{0}JSXJSXJSXJSXJSXJSXJSXJSXJSXJSXJSXJS{1}XJSX
{0}JSXJSXJSXJSXJSXJSXJSXJSXJSXJSXJSXJ{1}SXJSX
{0}JSXJSXJSXJSXJSXJSXJSXJSXJSXJSXJSX{1}JSXJSX
{0}JSXJSXJSXJSXJSXJSXJSXJSXJSXJSXJS{1}XJSXJSX
{0}JSXJSXJSXJSXJSXJSXJSXJSXJSXJSXJ{1}SXJSXJSX
{0}JSXJSXJSXJSXJSXJSXJSXJSXJSXJSX{1}JSXJSXJSX
{0}JSXJSXJSXJSXJSXJSXJSXJSXJSXJS{1}XJSXJSXJSX
{0}JSXJSXJSXJSXJSXJSXJSXJSXJSXJ{1}SXJSXJSXJSX
{0}JSXJSXJSXJSXJSXJSXJSXJSXJSX{1}JSXJSXJSXJSX
{0}JSXJSXJ   SXJS      XJSXJS{1}X{2}JSX{1}JSX{2}JSX{1}JSX
{0}JSXJSXJ   SXJ   SXJSXJSXJ{1}SXJ{2}SXJ{1}S{2}XJS{1}XJSX
{0}JSXJSXJ   SXJS   XJSXJSX{1}JSXJSX{2}JSX{1}JSXJSX
{0}JSXJSXJ   SXJSX   JSXJS{1}XJSXJS{2}XJSXJ{1}SXJSX
{0}JS   XJ   SXJSXJ   SXJ{1}SXJSXJ{2}SXJ{1}S{2}XJS{1}XJSX
{0}JSX       JS      XJS{1}XJSXJS{2}XJS{1}XJS{2}XJS{1}XJS
{0}JSXJSXJSXJSXJSXJSXJS{1}XJSXJSXJSXJSXJSXJSX
{0}JSXJSXJSXJSXJSXJSXJ{1}SXJSXJSXJSXJSXJSXJSX
",
            Language::Julia => "{0}               {2}_
{0}   {1}_       {0}_ {3}_{2}(_){4}_
{0}  {1}(_)     {0}| {3}(_) {4}(_)
{0}   _ _   _| |_  __ _
{0}  | | | | | | |/ _` |
{0}  | | |_| | | | (_| |
{0} _/ |\\__\'_|_|_|\\__\'_|
{0}|__/
",
            Language::Jupyter => "{0}                                 +%%%+
{0}                                $$$$$$$
{0}  +%+                           $$$$$$$
{0} $$$$$           {1}******          {0}*%%%*
{0}  *%*       {1}****************
{1}        ************************
{1}     ********              ********
{1}   ***                            ***
{1}  *                       {0}_          {1}*
{0}  _  _   _  _ __   _   _ | |_  ___  _ _
{0} | || | | || \'_ \\ | | | || __|/ _ \\| \'_|
{0} | || |_| || |_) || |_| || |_ | __/| |
{0} | | \\__,_|| .__/  \\__, | \\__|\\___||_|
{0}/_/        |_|     |___/
{1}  *                                  *
{1}   ***                            ***
{1}     ********              ********
{1}        ************************
{1}            ****************
{0}    +%%%+        {1}******
{0}   $$$$$$$
{0}   $$$$$$$
{0}    *%%%*
",
            Language::Kotlin => "{0}KOTLIN{2}KOTLINKOTLINKO{1}TLINKOTLINKOTLINKOTL
{0}KOTLINKO{2}TLINKOTLIN{1}KOTLINKOTLINKOTLINKO
{0}KOTLINKOTL{2}INKOTL{1}INKOTLINKOTLINKOTLIN
{0}KOTLINKOTLIN{2}KO{1}TLINKOTLINKOTLINKOTL
{0}KOTLINKOTLIN{1}KOTLINKOTLINKOTLINKO
{0}KOTLINKOTL{1}INKOTLINKOTLINKOTLIN
{0}KOTLINKO{1}TLINKOTLINKOTLINKOTL
{0}KOTLIN{1}KOTLINKOTLINKOTLINKO
{0}KOTL{1}INKOTLINKOTLINKOTLIN
{0}KO{1}TLINKOTLINKOTLINKOTL
{1}KOTLINKOTLINKOTLINKO{2}TL
{2}KO{1}TLINKOTLINKOTLIN{2}KOTLIN
{2}KOTL{1}INKOTLINKOTL{2}INKOTLINKO
{2}KOTLIN{1}KOTLINKO{2}TLINKOTLINKOTL
{2}KOTLINKO{1}TLIN{0}K{2}OTLINKOTLINKOTLIN
{2}KOTLINKOTL{0}INKOT{2}LINKOTLINKOTLINKO
{2}KOTLINKO{0}TLINKOTLI{2}NKOTLINKOTLINKOTL
{2}KOTLIN{0}KOTLINKOTLINK{2}OTLINKOTLINKOTLIN
{2}KOTL{0}INKOTLINKOTLINKOT{2}LINKOTLINKOTLINKO
{2}KO{0}TLINKOTLINKOTLINKOTLI{2}NKOTLINKOTLINKOTL
",
            Language::LLVM => "{0}KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK
{0}KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK
{0}KKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKKK
{0}KKKKKKKKK\"              \"KKKKKKKK
{0}KKKKKKK     KKKKKKKKKK     \"KKKKK
{0}KKKKK     KKKKKKKKKKKKKKK    \"KKK
{0}KKKK     KKKKKKKKKKKKKKKKK
{0}KKKK      KKKKKKKKKKKKKKKKK
{0}KKKK        KKKKKKKKKKKKKKKK
{0}KKKK           KKKKKKKKKKKKKK
{0}KKKK            KKKKKKKKKKKKK
{0}KKKK            ,KKKKKKKKKKKK
{0}KKKKKK,    ,     KKKKKKKKKKKK
{0}KKKKKKKK   KK,    `KKKKKKKKKK
{0}KKKKKKKKK  KKKKKKKKKKKKKKKKK
{0}KKKKKKKK,  ,KKKKKKKKKKKKKKK
{0} `KKKKKKKKKKKKKKKKKKKKKKK`
{0}   `KKKKKKKKKKKKKKKKKKK`
{0}      `KKKKKKKKKKKKKK`
",
            Language::Lisp => "{0}              ............
{0}         ********..............
{0}       *************.............
{0}     ****************..............
{0}   *******************...***.........
{0}  **...********...*****...***.........
{0} ***...*******...******....***.........
{0}****...******...*******....****.........
{0}*****...****...*******.....*****........
{0}******...**...******.......******.......
{0}*******......******.......***..***......
{0}********.....*****.......***....***.....
{0}*********....****.......***......***....
{0} *********...****......***.......***...
{0}  *********...***.....***........***..
{0}   *********...***...................
{0}     **************................
{0}       *************.............
{0}         **************........
{0}              ************
",
            Language::Lua => "{1}                 -- --
{1}         --                 --{0} @@@@
{1}      --      {0}@@@@@@@@@@@     @@@@@@
{0}           @@@@@@@@@@@@@@@@@   @@@@
{1}  --     {0}@@@@@@@@@@@@@@{1}@@@@{0}@@@     {1}--
{1} --    {0}@@@@@@@@@@@@@@@{1}@@@@@@{0}@@@@    {1}--
{0}      @@@@@@@@@@@@@@@@@{1}@@@@{0}@@@@@@
{1}--   {0}@@@{1}@@{0}@@@@@@@@@@@@@@@@@@@@@@@@   {1}--
{1}--   {0}@@@{1}@@{0}@@@@@@{1}@@{0}@@{1}@@{0}@@{1}@@@@@@{0}@@@@   {1}--
{0}     @@@{1}@@{0}@@@@@@{1}@@{0}@@{1}@@{0}@{1}@@{0}@@@{1}@@{0}@@@@
{1}--   {0}@@@{1}@@{0}@@@@@@{1}@@{0}@@{1}@@{0}@@@{1}@@@@@{0}@@@@   {1}--
{1}--   {0}@@@{1}@@{0}@@@@@@{1}@@{0}@@{1}@@{0}@{1}@@@{0}@@{1}@@{0}@@@@   {1}--
{0}      @@{1}@@@@@@@{0}@{1}@@@@@@{0}@{1}@@@@@@@@{0}@@
{1} --    {0}@@@@@@@@@@@@@@@@@@@@@@@@@    {1}--
{1}  --     {0}@@@@@@@@@@@@@@@@@@@@@     {1}--
{0}           @@@@@@@@@@@@@@@@@
{1}      --      {0}@@@@@@@@@@@      {1}--
{1}         --                 --
{1}                 -- --
",
            Language::Makefile => "{0}    _-`````-,           ,- \'- .
{0}  .\'   .- - |          | - -.  `.
{0} /.\'  /                     `.   \\
{0}:/   :      {1}_...   ..._      {0}``   :
{0}::   :     {1}/._ .`:\'_.._\\.    {0}||   :
{0}::    `._ {1}./  ,`  :    \\{0} . _.\'\'   .
{0}`:.      {1}/   |  -.  \\-. \\\\_{0}      /
{0}  \\:._ {1}_/  .\'   .{2}@{1})  \\{2}@{1}) ` `\\{0} ,.\'
{1}    {0}\'{1}_/,--\'       .- .\\,-.`--`.
{1}       ,\'/\'\'     (( \\ `  )
{1}        /\'/\'  \\    `-\'  (
{1}         \'/\'\'  `._,-----\'
{1}          \'\'/\'    .,---\'
{1}           \'\'/\'      ;:
{1}             \'\'/\'\'  \'\'/
{1}               \'\'/\'\'/\'\'
{1}                 \'/\'/\'
{1}                  `;
",
            Language::Markdown => "{0}#######  {1} ,#####. .#####.
{0}  ###    {1}########.########
{0}  ###    {1}#################
{0}  ###    {1}`###############\'
{0}  ###    {1} `#############\'
{0}  ###    {1}   `#########\'
{0}  ###    {1}     `#####\'
{0}#######  {1}       `#\'
{0}
{0}####     ####     ###
{0}#####   #####     ###
{0}######.######     ###
{0}### ##### ###     ###
{0}###  ###  ###   #######
{0}###   #   ###    #####
{0}###       ###     ###
{0}###       ###      #
",
            Language::Nim => "{0}                   ++
{0}       ++        ++++++        ++
{0}      ++++++++++++++++++++++++++++
{0}     ++++++++++++++++++++++++++++++
{0}++  ++++++++++++++++++++++++++++++++  ++
{0} ++++++++++++++++++++++++++++++++++++++
{0}  +++++++++++              +++++++++++
{0}   ++++++++                  ++++++++
{0}    +++++                      +++++
{1} ?   {0}++                          ++   {1}?
{1}  ??             ??????             ??
{1}   ???         ??????????         ???
{1}    ????     ??????????????     ????
{1}     ??????????????????????????????
{1}      ????????????????????????????
{1}       ??????????????????????????
{1}         ??????????????????????
{1}           ??????????????????
",
            Language::Nix => "{1}         :::.    {0}\':::::     ::::\'
{1}         \'::::    {0}\':::::.  ::::\'
{1}           ::::     {0}\'::::.:::::
{1}     ......:::::..... {0}::::::::
{1}    :::::::::::::::::. {0}::::::    {1}::::.
{1}   :::::::::::::::::::: {0}:::::.  {1}.::::\'
{0}         .....           {0}::::\' {1}:::::\'
{0}        :::::            {0}\'::\' {1}:::::\'
{0} ......:::::               {0}\' {1}::::::::::.
{0}:::::::::::                 {1}::::::::::::
{0} ::::::::: {1}..              {1}:::::
{0}    .:::: {1}.:::            {1}:::::
{0}   .::::  {1}:::::          {1}\'\'\'\'\'    {0}.....
{0}   ::::   {1}\':::::.  {0}......:::::::::::::\'
{0}    ::     {1}::::::. {0}\':::::::::::::::::\'
{1}           {1}.:::::::: {0}\'::::::::::
{1}          {1}.::::\'\'::::.     {0}\'::::.
{1}         {1}.::::\'   ::::.     {0}\'::::.
{1}        {1}.::::      ::::      {0}\'::::.
",
            Language::OCaml => "{0}///////////////////////////////////////
{0}///////////////////////////////////////
{0}///////////////////////////////////////
{0}///////////////////////////////////////
{0}///////////////////////////////////////
{0}///   \\////    \\///////////////////////
{0}//      //      /////////     .////////
{0}/                ///////         \\/////
{0}                  /////      //////////
{0}                            ///////////
{0}                           ////////////
{0}  //                    ///////////////
{0} /////////   ///   ////////////////////
{0}/////////  //////  ////////////////////
{0}////////  ///////  ////////////////////
{0}///////  ////////  ////////////////////
{0}//////  /////////  ////////////////////
",
            Language::ObjectiveC => "{0}888                                888
{0}8    8888   8       8        8888    8
{0}8   8    8  8               8    88  8
{0}8  8      8 8       8      8         8
{0}8  8      8 8 888   8      8         8
{0}8  8      8 88   8  8 ==== 8         8
{0}8  8      8 8    8  8      8      8  8
{0}8   8    8  88   8  8       8    88  8
{0}8    8888   8 888   8        88888   8
{0}888                 8              888
{0}                    8
{0}                  88Y
",
            Language::Odin => "{0}          @@@@@@@@@
{0}      @@@@     @@@   @@@
{0}    @@@@      @@@   @@@@@@
{1}  @@@@       @@@   @@@  @@@@
{1} @@@        @@@   @@@     @@@
{1}@@@        @@@   @@@       @@@
{2}@@@       @@@   @@@        @@@
{2}@@@      @@@   @@@         @@@
{2}@@@     @@@   @@@          @@@
{3}@@@    @@@   @@@           @@@
{3} @@@  @@@   @@@           @@@
{3}  @@@@@@   @@@          @@@@
{4}    @@@   @@@         @@@@
{4}         @@@        @@@@
{4}          @@@@@@@@@@
",
            Language::Org => "{2}                    j
{2}                   eL
{0}                Q {2}kD
{0}            Nt{1}yew{2}kQ{0}y
{1}       :r/2K{0}@Q@@@#N@@Qmir
{1}  -cDBQB6XXe{0}Q@@@@@@@@@@@@@Q@@g
{1} =NQQQR6XwPee{0}6@@@@@@@@@@@QdRm
{1}?#QB#HKXej{0}D@QQRNkPD9|
{1}SQNHDXwmXq{0}@@@QDR
{1}=D6XwmSm{0}D@Q@@QDH
{1} tXaZe{0}H@QQ@@@@QRdz
{1}   u{0}QRQ@@@@@@@@@QDDd
{0}     B@@@@@@@@@@@QDHDd
{0}         Syz*:\'--\'~;\\oM
",
            Language::Oz => "{0}                   ooooooooo
{0}               oooooo{1}zzz{0}oooooo
{0}            oooooo{1}zzzzzz{0}ooooooo
{0}         oooooo{1}zzz{0}ooo{1}zzz{0}oooooooo
{0}      ooooooooooooooo{1}zzz{0}ooooooooo
{0}   oooo    oooooooooo{1}zzz{0}ooo{1}zzz{0}oooo
{0} ooo   oooo   ooooooo{1}zzzzzz{0}oooooooo
{0}ooo   oooooo    ooooo{1}zzz{0}oooooooooooo
{0}ooo    oooooo    ooooooooooo   oooooo
{0}oooo    oooooo   oooooooo      ooooooo
{0} ooooo   oooo   oooooo   ooo   oooooooo
{0}  ooooooo    ooooooooooooooo   oooooooo
{0}   ooooooooooo{1}zzzz{0}oooooooooo   ooo   oo
{0}    ooooooo{1}zzz{0}oooo{1}zzz{0}ooooooo      oooo
{0}     ooooo{1}zzz{0}oooooo{1}zzzz{0}ooooo   ooooo
{0}      oooo{1}zzzz{0}oooooo{1}zzzz{0}ooooooooo
{0}       oooo{1}zzzz{0}oooooo{1}zzz{0}oooooo
{0}        ooooo{1}zzz{0}oooo{1}zzz{0}ooo
{0}         ooooooo{1}zzzz{0}oooo
{0}           ooooooooo
",
            Language::Pascal => "{0}█████{1}╗  {0}████{1}╗ {0}█████{1}╗ {0}████{1}╗ {0}████{1}╗ {0}██{1}╗
{0}██{1}╔═{0}██{1}╗{0}██{1}╔═{0}██{1}╗{0}██{1}╔══╝{0}██{1}╔══╝{0}██{1}╔═{0}██{1}╗{0}██{1}║
{0}█████{1}╔╝{0}██████{1}║{0}█████{1}╗{0}██{1}║   {0}██████{1}║{0}██{1}║
{0}██{1}╔══╝ {0}██{1}╔═{0}██{1}║╚══{0}██{1}║{0}██{1}║   {0}██{1}╔═{0}██{1}║{0}██{1}║
{0}██{1}║    {0}██{1}║ {0}██{1}║{0}█████{1}║╚{0}████{1}╗{0}██{1}║ {0}██{1}║{0}█████{1}╗
{1}╚═╝    ╚═╝ ╚═╝╚════╝ ╚═══╝╚═╝ ╚═╝╚════╝
",
            Language::Perl => "{0}                  ######
{0}    ###         #########
{0} ########      ##########
{0}#########     ############
{0}   ######   ###############
{0}  ####### ##################
{0}  ####### ###################
{0}  ############################
{0}  #############################
{0}  ########################### ##
{0}    ######################### ##
{0}     ###################  ### #
{0}          ##### #### ###  ### #
{0}          ####  #### ###   ##
{0}          ####  ###  ###    #
{0}           ##  ###   ###    #
{0}           ##   ##   ##     #
{0}           ##    #   #      #
{0}           #       ##       #
{0}           #       # #      #
{0}           #     ### ##     ##
{0}          ##
",
            Language::Perl6 => "{0} +@8DM#8W,
{0}#DM\"{1},ypy,{0}\"8#
{0}DDU {1}8M]N8u{0} DM
{0}8DD {1}TMD8M,{0}8M  {4}8
{0} 8D#=e@8MM^   {4}8
{0}  *MDw  {4},.,+#M`
{0}    \"8#                   {0},e88DDDD8m,
{0}      \"8 {3}x33#,           {0}z8D#M`9Dw \"9DW
{3}        JE   E {2}BBW.     {0}DM {1}p#Kw {0}D8   {0}JDM
{1} #pp#pr {3} JRFMy{2}#EEF{3}y#Rr, {0}DM{1} MD]8 {0}9DM {4}`N
{1}Z#{0}8#D]{1}D# {2}EE#EEEEE{3}`EW  E {0}8M,{1}\"RM`{0} 8DM  {4}D
{1}88{0}8]D]{1}D8 {2}EEM{1}#{2}EEE{1}E{2}Bp{3}TFF^  {0}*M888#`  {4}#M
{1}*#88EE8  {2} RRk{1}8BMM{2}#EEE,        {4}\'^\'
{1}   ``      {2}\'\"F*FFF*  {1},yw,
{1}                  ,#]{0}[D8{1}8W
{1}                  k8{0}]DDN8{1}8L
{1}                  \'8E{0}$DE8{1}8M
{1}                    R#E#R^
",
            Language::Php => "{0}            ################
{0}      ##########{1}/  |{0}##############
{0}   #############{1}|  |{0}#################
{0} #####{1}/   __   \\|   __   \\/   __   \\{0}###
{0}######{1}|  |{0}##{1}|  ||  |{0}##{1}|  ||  |{0}##{1}|  |{0}####
{0}######{1}|  |{0}##{1}/  ||  |{0}##{1}|  ||  |{0}##{1}/  |{0}####
{0} #####{1}|   ____ /|__|{0}##{1}|__||   ____ /{0}###
{0}   ###{1}|  |{0}################{1}|  |{0}#######
{1}      |_ /{0}################{1}|_ /{0}####
{0}            ################
",
            Language::PowerShell => "{0}         #########################
{0}        ####{1}####{0}#################
{0}       ######{1}####{0}###############
{0}      ########{1}####{0}#############
{0}     ##########{1}####{0}###########
{0}    #########{1}####{0}############
{0}   ########{1}####{0}#############
{0}  #######{1}####{0}##############
{0} ######{1}####{0}#####{1}######{0}####
{0}#########################
",
            Language::Processing => "{0}          PPPPPPPPPPPP
{0}      PPPPPPPPPPPPPPPPPPPP
{0}    PPPPPPPPPPPP{1}PPPPPP{0}PPPPPP
{0}   PPPPPPPPPPPPP{1}P{0}PPPP{1}PP{0}PPPPPP
{0}  PPPPPPPPPPPPPPPPPPP{1}PP{0}PPPPPPP
{0} PPPPPPPPPPPPPPPPPPP{1}PP{0}PPPPPPPPP
{0}PPPPPPPPPPP{1}PPPP{0}PP{1}PPPPP{0}PPPPPPPPPP
{0}PPPPPPPPPPPP{1}PPP{0}PPPPPP{1}PP{0}PPPPPPPPP
{0}PPPPPPPPPPPP{1}PPP{0}PPPPPP{1}PP{0}PPPPPPPPP
{0}PPPPPPPPPPPP{1}PPP{0}PP{1}PPPPP{0}PPPPPPPPPP
{0}PPPPPPPPPPPP{1}PPP{0}PPPPPPPPPPPPPPPPP
{0} PPPPPPPPPPP{1}PPP{0}PPPPPPPPPPPPPPPP
{0}  PPPPPPPPPP{1}PPP{0}PPPPPPPPPPPPPPP
{0}   PPPPPPP{1}PPPPPPP{0}PPPPPPPPPPPP
{0}    PPPPPPPPPPPPPPPPPPPPPPPP
{0}      PPPPPPPPPPPPPPPPPPPP
{0}          PPPPPPPPPPPP
",
            Language::Prolog => "{0}            ############   #
{0}       #################   ####
{0}     ###################   ######
{0}   #####################   #######
{0}  ######################   ########
{0} #######         #######   #########
{0}######  ###        #####   ##########
{0}#####  ####      #  ####   ##########
{0}#####  #####    ##  ####   ##########
{0}#####   #########   ####   ##########
{0}#####     #####   #######    ########
{0} ####           ###########       ##
{0}  ###   ###########################
{0}    #   ##########################
{0}        ########################
{0}        ######################
{0}           ################
",
            Language::Protobuf => "{0}      ;;;;;;;;     {2}::::::::
{0}     ;;;;;;;;       {2}::::::::
{0}    ;;;;;;;;         {2}::::::::
{1}   :{0};;;;;;;           {2}::::::::
{1}  :::{0};;;;;             {2}::::::::
{1} :::::{0};;;               {2}::::::::
{1}:::::::{0};                {3};{2}:::::::
{1}::::::::               {3};;;{2}:::::
{1} ::::::::             {3};;;;;{2}:::
{1}  ::::::::           {3};;;;;;;{2}:
{1}   ::::::::         {3};;;;;;;;
{1}    ::::::::       {3};;;;;;;;
{1}     ::::::::     {3};;;;;;;;
",
            Language::PureScript => "{0}           \\\\\\\\\\\\\\\\\\\\\\\\\\\\    \\\\\\\\\\
{0}            \\\\\\\\\\\\\\\\\\\\\\\\\\\\     \\\\\\\\\\
{0}    /////                        \\\\\\\\\\
{0}  /////      //////////////      /////
{0}/////       //////////////     /////
{0}\\\\\\\\\\                        /////
{0}  \\\\\\\\\\     \\\\\\\\\\\\\\\\\\\\\\\\\\\\
{0}    \\\\\\\\\\    \\\\\\\\\\\\\\\\\\\\\\\\\\\\
",
            Language::Python => "{0}               =========
{0}            ===============
{0}           =================
{0}          ===  ==============
{0}          ===================
{0}                   ==========
{0}   ========================== {1}=======
{0} ============================ {1}========
{0}============================= {1}=========
{0}============================ {1}==========
{0}========================== {1}============
{0}============ {1}==========================
{0}========== {1}============================
{0}========= {1}=============================
{0} ======== {1}============================
{0}  ======= {1}==========================
{1}          ==========
{1}          ===================
{1}          ==============  ===
{1}           =================
{1}            ===============
{1}               =========
",
            Language::Qml => "{0}****************************************
{0}****************************************
{0}****************************************
{0}****************************************
{0}****************************************
{0}*******{1}####{0}*****{1}###{0}*****{1}###{0}**{1}###{0}********
{0}*****{1}########{0}***{1}####{2},{0}**{1}####{2},{0}*{1}###{2},,{0}******
{0}****{1}###{2},,,,{1}###{2},{0}*{1}#####{2},{1}#####{2},,{1}###{2},,,,{0}****
{0}***{1}###{2},,,,,,{1}###{2},{1}###########{2},,{1}###{2},,,,,,{0}**
{0}***{1}###{2},,,,,,{1}###{2},{1}###{2},{1}###{2},{1}###{2},,{1}###{2},,,,,,,{0}*
{0}***{1}###{2},,,,,,{1}###{2},{1}###{2},,{1}#{2},,{1}###{2},,{1}###{2},,,,,,,,
{0}****{1}###{2},,,,{1}###{2},,{1}###{2},,,,,{1}###{2},,{1}###{2},,,,,,,,
{0}*****{1}########{2},,,{1}###{2},,,,,{1}###{2},,{1}########{2},,,
{0}*******{1}####{2},,,,,{1}###{2},,,,,{1}###{2},,{1}########{2},,,
{0}********{2},{1}#####{2},,,,,,,,,,,,,,,,,,,,,,,,,,
{0}*********{2},,,,,,,,,,,,,,,,,,,,,,,,,,,,,,,
{0}***********{2},,,,,,,,,,,,,,,,,,,,,,,,,,,,,
{0}*************{2},,,,,,,,,,,,,,,,,,,,,,,,,,,
{0}***************{2},,,,,,,,,,,,,,,,,,,,,,,,,
{0}*****************{2},,,,,,,,,,,,,,,,,,,,,,,
",
            Language::R => "{0}             .,,,,,,,,,,,,,
{0}       ,,,,,,,,,,,,,,,,,********
{0}    ,,,,,,,,,,,,,,,,,**************
{0}  ,,,,,,,,,,,,                  *****
{0} ,,,,,,,,,      {1}RRRRRRRRRRRRRRRR   {0}***
{0},,,,,,,,,       {1}RRRRRRRRRRRRRRRRRRR {0}***
{0},,,,,,,,        {1}RRRRRRRRRRRRRRRRRRRR {0}//
{0},,,,,,*         {1}RRRRRRR      RRRRRRR {0}//
{0},,,*****        {1}RRRRRRR     RRRRRRR  {0}//
{0} ********       {1}RRRRRRRRRRRRRRRRRR  {0}//
{0}   *********    {1}RRRRRRRRRRRRRR    {0}//
{0}      **********{1}RRRRRRR   RRRRRRR
{0}         *******{1}RRRRRRR    RRRRRRR
{1}                RRRRRRR     RRRRRRRR
",
            Language::Racket => "{0}            {2}.:--::////::--.`
{0}        {1}`/yNMMNho{2}////////////:.
{0}      {1}`+NMMMMMMMMmy{2}/////////////:`
{0}    `-:::{1}ohNMMMMMMMNy{2}/////////////:`
{0}   .::::::::{1}odMMMMMMMNy{2}/////////////-
{0}  -:::::::::::{1}/hMMMMMMMmo{2}////////////-
{0} .::::::::::::::{1}oMMMMMMMMh{2}////////////-
{0}`:::::::::::::{1}/dMMMMMMMMMMNo{2}///////////`
{0}-::::::::::::{1}sMMMMMMmMMMMMMMy{2}//////////-
{0}-::::::::::{1}/dMMMMMMs{0}:{1}+NMMMMMMd{2}/////////:
{0}-:::::::::{1}+NMMMMMm/{0}:::{1}/dMMMMMMm+{2}///////:
{0}-::::::::{1}sMMMMMMh{0}:::::::{1}dMMMMMMm+{2}//////-
{0}`:::::::{1}sMMMMMMy{0}:::::::::{1}dMMMMMMm+{2}/////`
{0} .:::::{1}sMMMMMMs{0}:::::::::::{1}mMMMMMMd{2}////-
{0}  -:::{1}sMMMMMMy{0}::::::::::::{1}/NMMMMMMh{2}//-
{0}   .:{1}+MMMMMMd{0}::::::::::::::{1}oMMMMMMMo{2}-
{0}    {1}`yMMMMMN/{0}:::::::::::::::{1}hMMMMMh.
{0}      {1}-yMMMo{0}::::::::::::::::{1}/MMMy-
{0}        {1}`/s{0}::::::::::::::::::{1}o/`
{0}            ``.---::::---..`
",
            Language::Renpy => "{0}       ++++++
{0}     ++++++++++
{0}    ++++++++++++
{0}   ++++++++++++++
{0}   ++++++++++++++++
{0}  +++++++++++++{1}***{0}+++
{0}  +++++++{1}***********
{0} +++++{1}**************
{0}+++{1}*****************
{0}++{1}********{2}#{1}**********
{1} *****{2}#{1}*{2}#{1}*{2}#{1}****{2}#{1}*{2}#{1}***
{1} *****{2}#{1}*{2}###{1}*{2}#{1}**{2}#{1}*{2}#{1}***
{1} *****{2}##########{1}*{2}#{1}***
{1} *****{2}##{3}**{2}####{3}**{2}##{1}***
{1} *****{2}##{3}**{2}####{3}**{2}##{1}***
{1} *****{2}############{1}***
{1} *****{2}#####{5}--{2}####{1}***
{1}  **{4}#####{2}#######{1}**
{4}   #{5}**{4}#{5}**{4}#{2}###{4}####
{4}   #{5}**{4}#{5}**{4}#{2}###{4}######
{4}   ##{5}*{4}#{5}*{4}##{6}++++{4}######
{4}    #####{6}++++++{4}#####
{4}     ###{6}++++++++{4}####
{6}     +++++++++++{4}####
{6}     ++++++++++{4}####
",
            Language::Ruby => "{0}                    ###{2}###{3}###{4}#{1}.{4}#
{0}                  ###{2}###{3}###{4}##{1}.{5}##
{0}                ##{1}.{2}###{3}###{4}###{1}.{5}###
{0}              ###{2}##{1}.{3}###{4}###{5}#{1}.{5}#{6}###
{0}            ###{2}###{3}##{1}.{4}###{5}##{1}.{6}###{7}##
{0}          ###{2}###{3}###{4}##{1}.{5}###{1}.{6}##{7}####
{0}        ###{2}###{3}###{4}###{5}##{1}.{6}#{1}.{6}#{7}######
{0}      #{1}.{0}*{2}***{3}***{4}***{5}***{6}**{1}.{7}###{8}#####
{0}    ###{1}.{2}##{3}###{4}###{5}###{6}##{1}.{7}##{1}.{8}#######
{0}  ####{2}#{1}.{2}#{3}###{4}###{5}###{6}#{1}.{6}#{7}###{8}#{1}.{8}######
{0}#####{2}##{1}.{3}###{4}###{5}###{1}.{6}##{7}###{8}###{1}.{8}#####
{0} #####{2}#{1}.{2}#{3}###{4}###{1}.{5}###{6}###{7}###{8}##{1}.{8}####
{0}  #####{1}.{2}##{3}###{1}.{4}##{5}###{6}###{7}###{8}###{1}.{9}###
{0}   ####{1}.{3}###{1}.{4}##{5}###{6}###{7}###{8}###{9}###{1}.{9}##
{0}    ###{1}.{2}#{1}.{3}##{4}###{5}###{6}###{7}###{8}###{9}###{1}.{9}#
",
            Language::Rust => "{0}                 R RR RR
{0}              R RRRRRRRR R          R
{0} R RR       R RRRRRRRRRRRRR R      RR
{0}rR RRR    R RRRRRRRRRRRRRRRRR R   RRR R
{0}RRR RR   RRRRRRRRRRRRRRRRRRRRRRR  RRRRR
{0} RRRRR  RRRRRRRRRRRRRRRRRRRRRRRR  RRRR
{0}  RRR RRRRRRRRRRRRRRRRRRRRRRRRRRRR RR
{0}    R  RRRRRRRRRR{1}=  {0}RR{1} = {0}RRRRRRRRRRR
{0}     RRRRRRRRRRRR{1}=  {0}RR{1} = {0}RRRRRRRRRR
{0}      RRRRRRRRRRR   RR   RRRRRRRRRR
{0}     RR==RRRRRRRRRRRRRRRRRRRRRR===RR
{0}     RR =  ==RRRRRRR  RRRRRR==  = RR
{0}      RR =     ===========     = RR
{0}       RR                        R
{0}        R                       R
{0}         R
",
            Language::Sass => "{0}            ,wppbbbbbp,
{0}       ,wpb@KP\"``` ``\"T@b
{0}    ,pb@P\"`            @@
{0}  ,b@P`               /@P
{0} p@b`               ,bK`
{0}{@@      \'w,  ,,wpbP*`
{0} 0@b        ````      ,pp  ;@@
{0}  \"0bw        ,bPK   ,K@L /PT@
{0}     \"0b, ,,pbP  @b .b Tb{\"  $bP\"\"\"*Tb,
{0}      ,/b@P &@  0@M.b  ,@K ,P @L      `b
{0}   ,pb\"  Ib @@ &h@bP ,pCpP bb*`       /`
{0}  p@`   ,@` `bb` T\"  \"\"`
{0}  @@w,pbK`
{0}  `***^
",
            Language::Scala => "{0}                        +
{0}                      +++
{0}          +++++++++++++++
{0}+++++++++++++++++++++++++
{0}+++++++++++++++++++++++++
{0}+++++++++++++++++++++++++
{0}+++++++++++++++++{1}-------
{0}+++{1}-------------------{0}+++
{1}        ---{0}++++++++++++++
{0}+++++++++++++++++++++++++
{0}+++++++++++++++++++++++++
{0}+++++++++++++++++++++++++
{0}+++++++++++++++++{1}-------
{0}+++{1}-------------------{0}+++
{1}        ---{0}++++++++++++++
{0}+++++++++++++++++++++++++
{0}+++++++++++++++++++++++++
{0}+++++++++++++++++++++++++
{0}+++++++++++++++
{0}+++
",
            Language::Scheme => "{0}  ////
{0} //  //
{0} /    //
{0}       //
{0}        //
{0}         //
{0}        ////
{0}       /// //
{0}      ///   //
{0}     ///     //
{0}    ///       //    /
{0}   ///         //  //
{0}  ///           ////
",
            Language::Sh => "{0}              ___       ___        ___
{0}             ####      ####       ####
{0}            ####      ####       ####
{0}      _____####______####___    ####
{0}     #######################   ####
{0}    #######################   ####
{0}        ####      ####       ####
{0}       ####      ####       ####
{0}  ____####______####____   ####
{0} #######################  ####
{0}#######################  ___
{0}   ####      ####       ####
{0}  ####      ####       ####
{0} ####      ####       ####
",
            Language::Solidity => "{0}MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM
{0}MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM
{0}MMMMMMMMMMMM{2}SS{3}SSSSSSSSSS{4}SS{0}MMMMMMMMMMMM
{0}MMMMMMMMMMM{2}SSSS{3}SSSSSSSS{4}SSSS{0}MMMMMMMMMMM
{0}MMMMMMMMMM{2}SSSSSS{3}SSSSSS{4}SSSSSS{0}MMMMMMMMMM
{0}MMMMMMMMM{2}SSSSSSSS{3}SSSS{4}SSSSSSSS{0}MMMMMMMMM
{0}MMMMMMMM{2}SSSSSSSSSS{3}SS{4}SSSSSSSSSS{0}MMMMMMMM
{0}MMMMMMMM{1}SSSSSSSSSS{0}MMMMMMMMMMMMMMMMMMMM
{0}MMMMMMMMM{1}SSSSSSSS{0}MMMMMMMMMMMMMMMMMMMMM
{0}MMMMMMMMMM{1}SSSSSS{0}MMMMMMMM{1}SS{0}MMMMMMMMMMMM
{0}MMMMMMMMMMM{1}SSSS{0}MMMMMMMM{1}SSSS{0}MMMMMMMMMMM
{0}MMMMMMMMMMMM{1}SS{0}MMMMMMMM{1}SSSSSS{0}MMMMMMMMMM
{0}MMMMMMMMMMMMMMMMMMMMM{1}SSSSSSSS{0}MMMMMMMMM
{0}MMMMMMMMMMMMMMMMMMMM{1}SSSSSSSSSS{0}MMMMMMMM
{0}MMMMMMMM{4}SSSSSSSSSS{3}SS{2}SSSSSSSSSS{0}MMMMMMMM
{0}MMMMMMMMM{4}SSSSSSSS{3}SSSS{2}SSSSSSSS{0}MMMMMMMMM
{0}MMMMMMMMMM{4}SSSSSS{3}SSSSSS{2}SSSSSS{0}MMMMMMMMMM
{0}MMMMMMMMMMM{4}SSSS{3}SSSSSSSS{2}SSSS{0}MMMMMMMMMMM
{0}MMMMMMMMMMMM{4}SS{3}SSSSSSSSSS{2}SS{0}MMMMMMMMMMMM
{0}MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM
{0}MMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMMM
",
            Language::Sql => "{0}   _..------.._
{0}.-~            ~-.
{0}|                |
{0}|\"-..________..-\"|
{0}|                | {1} ____   ___  _
{0}|                | {1}/ ___| / _ \\| |
{0}|\"-..________..-\"| {1}\\___ \\| | | | |
{0}|                | {1} ___) | |_| | |___
{0}|                | {1}|____/ \\__\\_|_____|
{0}|\"-..________..-\"|
{0}|                |
{0}|                |
{0} \"-..________..-\"
",
            Language::Svelte => "{0}SSSSSSSSSSSSSSSSSS{1}sssssssssss{0}SSSSSSSS
{0}SSSSSSSSSSSSSSS{1}sssssssssssssssss{0}SSSSS
{0}SSSSSSSSSSS{1}sssssssssss{0}SSSS{1}ssssssss{0}SSS
{0}SSSSSSSS{1}ssssssssss{0}SSSSSSSSSSS{1}sssssss{0}S
{0}SSSSS{1}sssssssss{0}SSSSSSSSSSSSSSSSS{1}sssss{0}S
{0}SSS{1}ssssssss{0}SSSSSSSSSS{1}sssss{0}SSSSSS{1}ssss{0}S
{0}S{1}sssssss{0}SSSSSSSSSS{1}sssssssss{0}SSSSS{1}ssss{0}S
{0}S{1}sssss{0}SSSSSSSSS{1}sssssssssssssssssssss{0}S
{0}S{1}sssss{0}SSSSSS{1}ssssssss{0}SSSSSS{1}ssssssssss{0}S
{0}S{1}sssss{0}SSSSS{1}ssssss{0}SSSSSSSSSSSS{1}ssssss{0}SS
{0}S{1}sssss{0}SSSSSSSSSSSSSSSSSSSSSSSSS{1}sssss{0}S
{0}SS{1}ssssss{0}SSSSSSSSSSSS{1}ssssss{0}SSSSS{1}sssss{0}S
{0}S{1}ssssssssss{0}SSSSSS{1}ssssssss{0}SSSSSS{1}sssss{0}S
{0}S{1}sssssssssssssssssssss{0}SSSSSSSSS{1}sssss{0}S
{0}S{1}ssss{0}SSSSS{1}sssssssss{0}SSSSSSSSSS{1}ssssss{0}SS
{0}S{1}ssss{0}SSSSSS{1}sssss{0}SSSSSSSSSS{1}ssssssss{0}SSS
{0}S{1}sssss{0}SSSSSSSSSSSSSSSSS{1}sssssssss{0}SSSSS
{0}S{1}sssssss{0}SSSSSSSSSSS{1}ssssssssss{0}SSSSSSSS
{0}SSS{1}ssssssss{0}SSSS{1}sssssssssss{0}SSSSSSSSSSS
{0}SSSSS{1}sssssssssssssssss{0}SSSSSSSSSSSSSSS
{0}SSSSSSSS{1}sssssssssss{0}SSSSSSSSSSSSSSSSSS
",
            Language::Svg => "{0}                 ......
{0}               ....{1}--{0}....
{0}        ....  {0}...{1}------{0}...  {0}....
{0}     ............{1}------{0}............
{0}    ...{1}-----{0}......{1}----{0}......{1}-----{0}...
{0}    ...{1}------{0}.....{1}----{0}.....{1}------{0}...
{0}    ...{1}--------{0}...{1}----{0}...{1}--------{0}...
{0}     .....{1}-------{0}.{1}----{0}.{1}-------{0}.....
{0}  ..........{1}----------------{0}..........
{0} ...{1}---{0}.......{1}------------{0}.......{1}---{0}...
{0}...{1}----------------------------------{0}...
{0}...{1}----------------------------------{0}...
{0} ...{1}---{0}.......{1}------------{0}.......{1}---{0}...
{0}  ..........{1}----------------{0}..........
{0}     .....{1}-------{0}.{1}----{0}.{1}-------{0}.....
{0}    ...{1}--------{0}...{1}----{0}...{1}--------{0}...
{0}    ...{1}------{0}.....{1}----{0}.....{1}------{0}...
{0}    ...{1}-----{0}......{1}----{0}......{1}-----{0}...
{0}     ............{1}------{0}............
{0}        ....  {0}...{1}------{0}...  {0}....
{0}               ....{1}--{0}....
{0}                 ......
",
            Language::Swift => "{0}                         :
{0}                          ::
{1}                           :::
{1}          :                ::::
{2}     :     :                ::::
{2}      :     ::              :::::
{3}       ::    :::             :::::
{3}        :::    :::           ::::::
{4}          :::   :::          :::::::
{4}           ::::  ::::        :::::::
{5}            :::::::::::      ::::::::
{5}              :::::::::::   :::::::::
{5}               ::::::::::::::::::::::
{6}                :::::::::::::::::::::
{6}                  :::::::::::::::::::
{6}:                   :::::::::::::::::
{7} ::                   ::::::::::::::
{7}   ::::              ::::::::::::::::
{7}    ::::::::::::::::::::::::::::::::::
{8}      :::::::::::::::::::::::::::::::::
{8}        :::::::::::::::::::::::::::::::
{8}          ::::::::::::::::::::::   :::::
{9}             .::::::::::::::.         ::
{9}
",
            Language::SystemVerilog => "{0}     _.._   _.._   _.._   _.._
{0}     _.._   _.._   _.._   _.._
{0} .................................
{0}.               {1}----              {0}.
{0}.          {1}--------------         {0}.
{0}.        {1}----       ---------     {0}.
{0}.      {1}---                -----   {0}.
{0}.     {1}-    #####  #     #  -----  {0}.
{0}.         {1}#     # #     #         {0}.
{0}.         {1}#       #     #         {0}.
{0}.          {1}#####  #     #         {0}.
{0}.               {1}#  #   #          {0}.
{0}.         {1}#     #   # #           {0}.
{0}.  {1}-----   #####     #      -     {0}.
{0}.   {1}-----                ---      {0}.
{0}.     {1}---------       ----        {0}.
{0}.         {1}--------------          {0}.
{0}.              {1}----               {0}.
{0} .................................
{0}     _.._   _.._   _.._   _.._
{0}     _.._   _.._   _.._   _.._
",
            Language::Tcl => "{0}          //
{2}      . /{0}////
{2}     /{0}/////// .
{2}     //{0}//{1}/{0}/////
{2}    //{0}//{1}/{0}/////
{2}  . //{0}/{1}//{0}////
{2}  //{0}//{1}//{0}////
{2}  //{0}/{1}//{0}/////
{2}  /{0}//{1}//{0}////
{2}  /{0}/{1}//{0}////  .
{2}. /{0}/{1}//{0}/////
{2} /{0}/{1}//{0}////
{2}  /{1}//{0}//
{0}   {1}//
{0}   {1}//
{0}    {1}/
{0}     {1}/
",
            Language::Tex => "{0}$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
{0}$$$            $$$$$$$      $$$$$     $$
{0}$$  $$$$  $$$$  $$$$$$$$$  $$$$$$$ $$$$$
{0}$$ $$$$$  $$$$$ $$$$$$$$$$  $$$$$ $$$$$$
{0}$$ $$$$$  $$$          $$$$  $$$ $$$$$$$
{0}$$ $$$$$  $$$$$  $$$$$  $$$$  $ $$$$$$$$
{0}$$$$$$$$  $$$$$  $$$$$$ $$$$$  $$$$$$$$$
{0}$$$$$$$$  $$$$$  $$$$$$ $$$$$  $$$$$$$$$
{0}$$$$$$$$  $$$$$  $$$$$$$$$$$$   $$$$$$$$
{0}$$$$$$$$  $$$$$  $$$ $$$$$$$ $$  $$$$$$$
{0}$$$$$$$$  $$$$$      $$$$$$ $$$$  $$$$$$
{0}$$$$$$$$  $$$$$  $$$ $$$$$ $$$$$$  $$$$$
{0}$$$$$$$$  $$$$$  $$$$$$$$ $$$$$$$$  $$$$
{0}$$$$$        $$  $$$$$     $$$$$$     $$
{0}$$$$$$$$$$$$$$$  $$$$$$$ $$$$$$$$$$$$$$$
{0}$$$$$$$$$$$$$$$  $$$$$$ $$$$$$$$$$$$$$$$
{0}$$$$$$$$$$$$$           $$$$$$$$$$$$$$$$
{0}$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$$
",
            Language::Toml => "{0}[[[[[[[[                    ]]]]]]]]
{0}[[[[[[[[                    ]]]]]]]]
{0}[[[[                            ]]]]
{0}[[[[      {1}TTTTTTTTTTTTTTTT{0}      ]]]]
{0}[[[[      {1}TTTTTTTTTTTTTTTT{0}      ]]]]
{0}[[[[            {1}TTTT{0}            ]]]]
{0}[[[[            {1}TTTT{0}            ]]]]
{0}[[[[            {1}TTTT{0}            ]]]]
{0}[[[[            {1}TTTT{0}            ]]]]
{0}[[[[            {1}TTTT{0}            ]]]]
{0}[[[[            {1}TTTT{0}            ]]]]
{0}[[[[            {1}TTTT{0}            ]]]]
{0}[[[[            {1}TTTT{0}            ]]]]
{0}[[[[            {1}TTTT{0}            ]]]]
{0}[[[[            {1}TTTT{0}            ]]]]
{0}[[[[            {1}TTTT{0}            ]]]]
{0}[[[[[[[[                    ]]]]]]]]
{0}[[[[[[[[                    ]]]]]]]]
",
            Language::Tsx => "{0}TSXTSXTSXTSXTSXTSXTSXTSXTSXTSXTSXTSX{1}TSX
{0}TSXTSXTSXTSXTSXTSXTSXTSXTSXTSXTSXTS{1}XTSX
{0}TSXTSXTSXTSXTSXTSXTSXTSXTSXTSXTSXT{1}SXTSX
{0}TSXTSXTSXTSXTSXTSXTSXTSXTSXTSXTSX{1}TSXTSX
{0}TSXTSXTSXTSXTSXTSXTSXTSXTSXTSXTS{1}XTSXTSX
{0}TSXTSXTSXTSXTSXTSXTSXTSXTSXTSXT{1}SXTSXTSX
{0}TSXTSXTSXTSXTSXTSXTSXTSXTSXTSX{1}TSXTSXTSX
{0}TSXTSXTSXTSXTSXTSXTSXTSXTSXTS{1}XTSXTSXTSX
{0}TSXTSXTSXTSXTSXTSXTSXTSXTSXT{1}SXTSXTSXTSX
{0}TSXTSXTSXTSXTSXTSXTSXTSXTSX{1}TSXTSXTSXTSX
{0}TS{2}XTSXTSXTS{0}XTSX{2}TSXTSX{0}TSXTS{1}X{2}TSX{1}TSX{2}TSX{1}TSX
{0}TSXTS{2}XTS{0}XTSXTS{2}XTS{0}XTSXTSXT{1}SXT{2}SXT{1}S{2}XTS{1}XTSX
{0}TSXTS{2}XTS{0}XTSXTSX{2}TSX{0}TSXTSX{1}TSXTSX{2}TSX{1}TSXTSX
{0}TSXTS{2}XTS{0}XTSXTSXT{2}SXT{0}SXTS{1}XTSXTS{2}XTSXT{1}TSTSX
{0}TSXTS{2}XTS{0}XTSXTSXTS{2}XTS{0}XT{1}SXTSXT{2}SXT{1}S{2}XTS{1}XTSX
{0}TSXTS{2}XTS{0}XTSXT{2}SXTSXT{0}SX{1}TSXTSX{2}TSX{1}TSX{2}TSX{1}TSX
{0}TSXTSXTSXTSXTSXTSXTS{1}XTSXTSXTSXTSXTSXTSX
{0}TSXTSXTSXTSXTSXTSXT{1}SXTSXTSXTSXTSXTSXTSX
",
            Language::TypeScript => "{0}TSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTS
{0}TSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTS
{0}TSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTS
{0}TSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTS
{0}TSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTS
{0}TSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTS
{0}TSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTS
{0}TSTSTSTS{1}TSTSTSTSTSTSTS{0}TSTS{1}TSTSTS{0}TSTSTS
{0}TSTSTSTS{1}TSTSTSTSTSTSTS{0}TS{1}TSTSTSTSTS{0}TSTS
{0}TSTSTSTSTSTST{1}STST{0}STSTSTS{1}TSTST{0}TSTSTSTST
{0}TSTSTSTSTSTST{1}STST{0}STSTSTST{1}STSTS{0}TSTSTSTS
{0}TSTSTSTSTSTST{1}STST{0}STSTSTSTST{1}STSTS{0}TSTSTS
{0}TSTSTSTSTSTST{1}STST{0}STSTSTSTSTST{1}STSTS{0}TSTS
{0}TSTSTSTSTSTST{1}STST{0}STSTSTSTSTSTS{1}TSTST{0}TST
{0}TSTSTSTSTSTST{1}STST{0}STSTSTST{1}STSTSTSTST{0}STS
{0}TSTSTSTSTSTST{1}STST{0}STSTSTSSTS{1}TSTSTS{0}TSTST
{0}TSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTS
{0}TSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTSTS
",
            Language::Vala => "{0} ###################################
{0}#####################################
{0}#####################################
{0}############{1}######{0}##########{1}##{0}#######
{0}##########{1}###{0}#{1}####{0}#########{1}##{0}########
{0}########{1}###{0}###{1}####{0}########{1}##{0}#########
{0}#######{1}###{0}####{1}####{0}#######{1}##{0}##########
{0}######{1}###{0}#####{1}####{0}######{1}##{0}###########
{0}######{1}###{0}#####{1}####{0}#####{1}##{0}############
{0}########{1}#{0}#####{1}####{0}####{1}##{0}#############
{0}##############{1}####{0}###{1}##{0}##############
{0}##############{1}####{0}##{1}##{0}###############
{0}##############{1}####{0}#{1}##{0}################
{0}##############{1}######{0}#################
{0}##############{1}#####{0}##################
{0}##############{1}####{0}###################
{0}#####################################
{0}#####################################
{0} ###################################
",
            Language::Verilog => "{0}        _.._    _.._    _.._
{0}        _.._    _.._    _.._
{0}        _.._    _.._    _.._
{0}     _......................._
{0}    _.{1}-----             -----{0}._
{0}_..._.{1} ---               --- {0}._..._
{0}_..._.{1}  ---             ---  {0}._..._
{0}    _.{1}   ---           ---   {0}._
{0}    _.{1}    ---         ---    {0}._
{0}_..._.{1}     ---       ---     {0}._..._
{0}_..._.{1}      ---     ---      {0}._..._
{0}    _.{1}       ---   ---       {0}._
{0}    _.{1}        --- ---        {0}._
{0}_..._.{1}         -----         {0}._..._
{0}_..._.{1}          ---          {0}._..._
{0}    _.{1}           -           {0}._
{0}     _......................._
{0}        _.._    _.._    _.._
{0}        _.._    _.._    _.._
{0}        _.._    _.._    _.._
",
            Language::Vhdl => "{0}        |  |  |  |
{0}       {1}------------
{0}    --{1}|    {2}----    {1}|{0}--
{0}    --{1}|   {2}|    |   {1}|{0}--
{0}    --{1}|   {2}|    |   {1}|{0}--
{0}    --{1}|    {2}----    {1}|{0}--
{0}       {1}------------
{0}        |  |  |  |
{2}__     ___   _ ____  _
{2}\\ \\   / / | | |  _ \\| |
{2} \\ \\ / /| |_| | | | | |
{2}  \\ V / |  _  | |_| | |___
{2}   \\_/  |_| |_|____/|_____|
",
            Language::VimScript => "{1}     ________{0}  ++    {1}________
{1}    /{2}VVVVVVVV{1}\\{0}++++  {1}/{2}VVVVVVVV{1}\\
{1}    \\{2}VVVVVVVV{1}/{0}++++++{1}\\{2}VVVVVVVV{1}/
{1}     |{2}VVVVVV{1}|{0}++++++++{1}/{2}VVVVV{1}/\'
{1}     |{2}VVVVVV{1}|{0}++++++{1}/{2}VVVVV{1}/\'
{0}    +{1}|{2}VVVVVV{1}|{0}++++{1}/{2}VVVVV{1}/\'{0}+
{0}  +++{1}|{2}VVVVVV{1}|{0}++{1}/{2}VVVVV{1}/\'{0}+++++
{0}+++++{1}|{2}VVVVVV{1}|/{2}VVV{1}___{0}++++++++++
{0}  +++{1}|{2}VVVVVVVVVV{1}/{2}##{1}/ {0}+{1}_{0}+{1}_{0}+{1}_{0}+{1}_
{0}    +{1}|{2}VVVVVVVVV{1}___ {0}+{1}/{2}#{1}_{2}#{1},{2}#{1}_{2}#{1},\\
{1}     |{2}VVVVVVV{1}//{2}##{1}/{0}+{1}/{2}#{1}/{0}+{1}/{2}#{1}/\'/{2}#{1}/
{1}     |{2}VVVVV{1}/\'{0}+{1}/{2}#{1}/{0}+{1}/{2}#{1}/{0}+{1}/{2}#{1}/ /{2}#{1}/
{1}     |{2}VVV{1}/\'{0}++{1}/{2}#{1}/{0}+{1}/{2}#{1}/ /{2}#{1}/ /{2}#{1}/
{1}     \'{2}V{1}/\'  /{2}##{1}//{2}##{1}//{2}##{1}//{2}###{1}/
{0}              ++
",
            Language::VisualBasic => "{1}             ::::::::::
{1}         ::::::::::::::::::
{1}      ::::::::::::::::::::::::
{0}    &&&&{1}::::::::::::::::::::::::
{0}  &&&&&&&&{1}::::::::::::::::::::::::
{0} &&&&{2}##{0}&&&&&{1}::::::{2}##{1}:::{2}######{1}::::::
{0}&&&&&&{2}##{0}&&&&&&{1}:::{2}##{1}::::{2}#{1}:::::{2}##{1}:::::
{0}&&&&&&&{2}##{0}&&&&&&&{2}##{1}:::::{2}#{1}:::::{2}##{1}:::::
{0}&&&&&&&&{2}##{0}&&&&&{2}##{0}&{1}:::::{2}#######{1}::::::
{0}&&&&&&&&&{2}##{0}&&&{2}##{0}&&&&{1}:::{2}#{1}::::::{2}##{1}::::
{0}&&&&&&&&&&{2}##{0}&{2}##{0}&&&&&&&{1}:{2}#{1}::::::{2}##{1}::::
{0} &&&&&&&&&&{2}###{0}&&&&&&&&&{2}######{1}::::::
{0}  &&&&&&&&&&&&&&&&&&&&&&&&{1}::::::::
{0}    &&&&&&&&&&&&&&&&&&&&&&&&{1}::::
{0}      &&&&&&&&&&&&&&&&&&&&&&&&
{0}         &&&&&&&&&&&&&&&&&&
{0}             &&&&&&&&&&
",
            Language::Vue => "{0}VUE{1}\\\\\\\\\\                /////{0}VUE
{0} VUE{1}\\\\\\\\\\              /////{0}VUE
{0}  VUE{1}\\\\\\\\\\            /////{0}VUE
{0}   VUE{1}\\\\\\\\\\          /////{0}VUE
{0}    VUE{1}\\\\\\\\\\        /////{0}VUE
{0}     VUE{1}\\\\\\\\\\      /////{0}VUE
{0}      VUE{1}\\\\\\\\\\    /////{0}VUE
{0}       VUE{1}\\\\\\\\\\  /////{0}VUE
{0}        VUE{1}\\\\\\\\\\/////{0}VUE
{0}         VUE{1}\\\\\\\\////{0}VUE
{0}          VUE{1}\\\\\\///{0}VUE
{0}           VUE{1}\\\\//{0}VUE
{0}            VUE{1}||{0}VUE
{0}             VUEVUE
{0}              VUEV
",
            Language::WebAssembly => "{0}:::::::::::             ::::::::::::
{0}::::::::::::           :::::::::::::
{0}:::::::::::::::     ::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::
{0}::::::::::::::::::::::::::::::::::::
{0}::::::::::::{1}WW{0}:::{1}WW{0}:::{1}WW{0}::::{1}AA{0}::::::
{0}::::::::::::{1}WW{0}:::{1}WW{0}:::{1}WW{0}:::{1}AAAA{0}:::::
{0}::::::::::::{1}WW{0}:::{1}WW{0}:::{1}WW{0}::{1}AA{0}::{1}AA{0}::::
{0}:::::::::::::{1}WW{0}:{1}WWWW{0}:{1}WW{0}::{1}AAAAAAAA{0}:::
{0}::::::::::::::{1}WWW{0}::{1}WWW{0}::{1}AA{0}::::::{1}AA{0}::
{0}::::::::::::::::::::::::::::::::::::
",
            Language::Wolfram => "{0}             OOOOOOOOOOOOOO
{0}         OOOOOO  OOOOOOOOOOOOOO
{0}       OOOOOO  {1}WW{0} OOOO OOOOOOOOOOO
{0}     OOOOOOO  {1}WWW {0}OOO {1}W{0} OOOOOOOOOOOO
{0}   OOOOOOOO  {1}WWWWW {0}O {1}WW{0} OOOOOOOOOOOOO
{0}  OOOOOOOO  {1}WWWWWW  WWW{0} OOOOOOOOOOOOOO
{0} OOOOOOOOO  {1}WWWWWWW WWW{0} OOOOOOOOOOOOOOO
{0} OOOOOOO  {1}WWWWWWWWWW WW{0} OOOOOOOOOOOOOOO
{0}OOOOOOO  {1}WWWWWWWWWWWWWW{0}  OOOOOOOOOOOOOOO
{0}OOOOOO  {1}WWWWWWWWWWWWWWWWW{0}   OOOOOOOOOOOO
{0}OOOOO  {1}WWW WWWWWWWWW   WWWWW{0}   OOOOOOOOO
{0}OOO   {1}WW  WWWWWWWWWWWWWWWWWWWWW{0}  OOOOOOO
{0} O   {1}WWWW  WWWWWWWWWWWWWWWWWWWWW{2}D{0}  OOOO
{0}    {1}WWWW  WWWWWWWWWWWWWWWWWWWWWW{0}  OOOOO
{1}   WWWWW..............  {0}.........OOOOO
{1}    WWWWWWWWWWWWWWWWWW{0}   OOOOOOOOOOOO
{1}     WWWWWWWWWWWWWWWWWW{0}    OOOOOOOO
{1}       WWWWWWWWWWWWWWWWW{0}    OOOOOO
{1}         WWWWWWWWWWWWWWWW{0}     OO
{1}             WWWWWWWWWWWWW{0}
",
            Language::XSL => "{0}                       :::
{0}       :::::          :::  :::::
{0}     :::::           :::     :::::
{0}   :::::            :::        :::::
{0} :::::             :::           :::::
{0}:::::             :::             :::::
{0} :::::           :::             :::::
{0}   :::::        :::            :::::
{0}     :::::     :::           :::::
{0}       :::::  :::          :::::
{0}             :::
",
            Language::Xaml => "{0}        :::::::::::::::::::::..
{0}       :::{1}------{0}::::::::::::....
{0}      :::{1}------{0}::::::::::::..{1}-{0}...
{0}     :::{1}------{0}::::::::::::..{1}---{0}...
{0}    :::{1}------{0}::::::::::::..{1}-----{0}...
{0}   :::{1}------{0}::::::::::::...{1}------{0}...
{0}  :::{1}------{0}::::::::::::.....{1}------{0}...
{0} :::{1}------{0}::::::::::::.......{1}------{0}...
{0}:::{1}------{0}::::::::::::.........{1}------{0}...
{0} :::{1}------{0}::::::::::::.......{1}------{0}...
{0}  :::{1}------{0}::::::::::::.....{1}------{0}...
{0}   :::{1}------{0}::::::::::::...{1}------{0}...
{0}    :::{1}------{0}::::::::::::..{1}-----{0}...
{0}     :::{1}------{0}::::::::::::..{1}---{0}...
{0}      :::{1}------{0}::::::::::::..{1}-{0}...
{0}       :::{1}------{0}::::::::::::....
{0}        :::::::::::::::::::::..
",
            Language::Xml => "{0}  __{1} __  _  __ __  _    {2}   __{0}__
{0} / /{1} \\ \\/  |  \\  \\| |   {2}  / /{0}\\ \\
{0}< < {1}  \\ \\  |     || |_  {2} / / {0} > >
{0} \\_\\{1} _/\\_\\ |_|_|_||___| {2}/_/  {0}/_/
",
            Language::Yaml => "{0}__    __  __   __    __   _
{0}\\ \\  / / /  | |  \\  /  | | |
{0} \\ \\/ / / | | | \\ \\/ / | | |.
{0}  \\  / / /| | | |\\__/| | | | .
{0}  / / / / | | | |    | | | |  .
{0} / / / /  | | | |    | | | |___.
{0}/_/ /_/   |_| |_|    |_| |______\\
",
            Language::Zig => "{0}                                     z
{0}                                  zzz
{0}                             zzzzzz
{0}zzzzzzzzzzz  zzzzzzzzzzzzzzzzzzzz  zzz
{0}zzzzzzzzz  zzzzzzzzzzzzzzzzzzzz  zzzzz
{0}zzzzzzz  zzzzzzzzzzzzzzzzzzzz  zzzzzzz
{0}zzzzz                zzzzzz      zzzzz
{0}zzzzz              zzzzzz        zzzzz
{0}zzzzz            zzzzzz          zzzzz
{0}zzzzz          zzzzzz            zzzzz
{0}zzzzz        zzzzzz              zzzzz
{0}zzzzz      zzzzzz                zzzzz
{0}zzzzzzz  zzzzzzzzzzzzzzzzzzzz  zzzzzzz
{0}zzzzz  zzzzzzzzzzzzzzzzzzzz  zzzzzzzzz
{0}zzz  zzzzzzzzzzzzzzzzzzzz  zzzzzzzzzzz
{0}   zzzzzz
{0} zzz
{0}z
",
            Language::Zsh => "{0}ZSHZSHZSHZSHZSHZSHZSHZSHZSHZSHZS
{0}ZSHZSHZSHZSHZSHZSHZSHZSHZSHZSHZS
{0}ZSHZ     ZSHZSHZSHZSHZSHZSHZSHZS
{0}ZSHZSH     SHZSHZSHZSHZSHZSHZSHZ
{0}ZSHZSHZS     SHZSHZSHZSHZSHZSHZS
{0}ZSHZSHZSHZ     HZSHZSHZSHZSHZSHZ
{0}ZSHZSHZSHZSH     ZSHZSHZSHZSHZSH
{0}ZSHZSHZSHZ     SHZSHZSHZSHZSHZSH
{0}ZSHZSHZS     ZSHZSHZSHZSHZSHZSHZ
{0}ZSHZSH     SHZSHZSHZSHZSHZSHZSHZ
{0}ZSHZ     ZSHZSH             SHZS
{0}ZSHZSHZSHZSHZSHZSHZSHZSHZSHZSHZS
{0}ZSHZSHZSHZSHZSHZSHZSHZSHZSHZSHZS
",
            
        }
    }

    pub fn get_colors(&self, true_color: bool) -> Vec<DynColors> {
        let colors = match self {
            Language::ABNF => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(136, 136, 136),
                            ])
                    ,
                },
            Language::Abap => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(27, 56, 125),
                            Rgb(238, 238, 238),
                            ])
                    ,
                },
            Language::Ada => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Blue),],
                    true_colors: Some(vec![Rgb(255, 255, 255),
                            Rgb(0, 24, 201),
                            Rgb(12, 10, 124),
                            ])
                    ,
                },
            Language::Agda => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Arduino => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),],
                    true_colors: None
                    ,
                },
            Language::Assembly => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Green),],
                    true_colors: None
                    ,
                },
            Language::AutoHotKey => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Green),],
                    true_colors: Some(vec![Rgb(255, 255, 255),
                            Rgb(17, 152, 16),
                            ])
                    ,
                },
            Language::Bash => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Green),],
                    true_colors: None
                    ,
                },
            Language::C => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(100, 154, 210),
                            Rgb(0, 66, 131),
                            Rgb(0, 89, 157),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::CMake => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Green),Ansi(AnsiColors::Red),Ansi(AnsiColors::Black),],
                    true_colors: None
                    ,
                },
            Language::CSharp => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Magenta),Ansi(AnsiColors::Magenta),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(155, 79, 151),
                            Rgb(103, 33, 122),
                            Rgb(128, 55, 136),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Ceylon => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Yellow),],
                    true_colors: Some(vec![Rgb(194, 126, 16),
                            Rgb(221, 161, 46),
                            Rgb(209, 145, 31),
                            Rgb(204, 139, 24),
                            Rgb(171, 112, 8),
                            ])
                    ,
                },
            Language::Clojure => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Green),],
                    true_colors: None
                    ,
                },
            Language::CoffeeScript => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),],
                    true_colors: None
                    ,
                },
            Language::ColdFusion => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Blue),],
                    true_colors: Some(vec![Rgb(229, 243, 252),
                            Rgb(39, 69, 80),
                            ])
                    ,
                },
            Language::Coq => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(191, 140, 94),
                            Rgb(213, 190, 153),
                            ])
                    ,
                },
            Language::Cpp => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(100, 154, 210),
                            Rgb(0, 66, 131),
                            Rgb(0, 89, 157),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Crystal => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Black),],
                    true_colors: None
                    ,
                },
            Language::Css => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::D => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),],
                    true_colors: None
                    ,
                },
            Language::Dart => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Blue),],
                    true_colors: Some(vec![Rgb(0, 163, 231),
                            Rgb(66, 223, 205),
                            Rgb(1, 89, 125),
                            ])
                    ,
                },
            Language::Dockerfile => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Default),Ansi(AnsiColors::Cyan),],
                    true_colors: None
                    ,
                },
            Language::Elisp => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Magenta),Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Elixir => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Magenta),],
                    true_colors: None
                    ,
                },
            Language::Elm => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Green),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Cyan),],
                    true_colors: None
                    ,
                },
            Language::Emojicode => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Green),Ansi(AnsiColors::Magenta),Ansi(AnsiColors::Magenta),Ansi(AnsiColors::Magenta),],
                    true_colors: Some(vec![Rgb(119, 178, 85),
                            Rgb(146, 102, 204),
                            Rgb(170, 141, 216),
                            Rgb(116, 78, 170),
                            ])
                    ,
                },
            Language::Erlang => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),],
                    true_colors: None
                    ,
                },
            Language::FSharp => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Cyan),],
                    true_colors: None
                    ,
                },
            Language::Fish => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Yellow),],
                    true_colors: None
                    ,
                },
            Language::Forth => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),],
                    true_colors: None
                    ,
                },
            Language::FortranLegacy => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Green),Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Red),],
                    true_colors: None
                    ,
                },
            Language::FortranModern => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Green),Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Red),],
                    true_colors: None
                    ,
                },
            Language::GdScript => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(69, 141, 192),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Glsl => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Magenta),],
                    true_colors: Some(vec![Rgb(84, 135, 166),
                            Rgb(188, 37, 142),
                            ])
                    ,
                },
            Language::Go => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Default),Ansi(AnsiColors::Yellow),],
                    true_colors: Some(vec![Rgb(116, 205, 221),
                            Rgb(255, 255, 255),
                            Rgb(246, 210, 162),
                            ])
                    ,
                },
            Language::Graphql => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Magenta),],
                    true_colors: None
                    ,
                },
            Language::Groovy => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Haskell => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Magenta),Ansi(AnsiColors::Blue),],
                    true_colors: Some(vec![Rgb(69, 58, 98),
                            Rgb(94, 80, 134),
                            Rgb(143, 78, 139),
                            ])
                    ,
                },
            Language::Haxe => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Yellow),],
                    true_colors: Some(vec![Rgb(250, 178, 11),
                            Rgb(246, 153, 18),
                            Rgb(244, 114, 22),
                            ])
                    ,
                },
            Language::Hcl => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Magenta),Ansi(AnsiColors::Magenta),],
                    true_colors: Some(vec![Rgb(95, 67, 233),
                            Rgb(64, 64, 178),
                            ])
                    ,
                },
            Language::Hlsl => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Green),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Yellow),],
                    true_colors: Some(vec![Rgb(246, 83, 20),
                            Rgb(124, 187, 0),
                            Rgb(0, 161, 241),
                            Rgb(255, 187, 0),
                            ])
                    ,
                },
            Language::HolyC => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(251, 254, 103),
                            Rgb(11, 68, 157),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Html => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Idris => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),],
                    true_colors: None
                    ,
                },
            Language::Java => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Blue),],
                    true_colors: Some(vec![Rgb(244, 67, 54),
                            Rgb(22, 101, 192),
                            ])
                    ,
                },
            Language::JavaScript => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),],
                    true_colors: Some(vec![Rgb(236, 230, 83),
                            ])
                    ,
                },
            Language::Json => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Black),],
                    true_colors: None
                    ,
                },
            Language::Jsonnet => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Black),],
                    true_colors: None
                    ,
                },
            Language::Jsx => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Magenta),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(236, 230, 83),
                            Rgb(182, 132, 211),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Julia => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Green),Ansi(AnsiColors::Red),Ansi(AnsiColors::Magenta),],
                    true_colors: None
                    ,
                },
            Language::Jupyter => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(255, 255, 255),
                            Rgb(255, 112, 15),
                            Rgb(158, 158, 158),
                            ])
                    ,
                },
            Language::Kotlin => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Magenta),],
                    true_colors: None
                    ,
                },
            Language::LLVM => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),],
                    true_colors: Some(vec![Rgb(152, 1, 46),
                            ])
                    ,
                },
            Language::Lisp => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Lua => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(19, 64, 116),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Makefile => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Red),],
                    true_colors: Some(vec![Rgb(255, 255, 255),
                            Rgb(250, 236, 154),
                            Rgb(97, 0, 0),
                            ])
                    ,
                },
            Language::Markdown => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Red),],
                    true_colors: None
                    ,
                },
            Language::Nim => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Nix => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Blue),],
                    true_colors: None
                    ,
                },
            Language::OCaml => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),],
                    true_colors: None
                    ,
                },
            Language::ObjectiveC => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Blue),],
                    true_colors: None
                    ,
                },
            Language::Odin => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Blue),],
                    true_colors: Some(vec![Rgb(38, 90, 153),
                            Rgb(52, 115, 190),
                            Rgb(63, 136, 221),
                            Rgb(71, 151, 243),
                            Rgb(73, 154, 247),
                            ])
                    ,
                },
            Language::Org => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Green),Ansi(AnsiColors::Red),Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Oz => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(252, 175, 62),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Pascal => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Perl => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),],
                    true_colors: None
                    ,
                },
            Language::Perl6 => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Red),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Default),Ansi(AnsiColors::Green),],
                    true_colors: Some(vec![Rgb(91, 0, 253),
                            Rgb(255, 0, 94),
                            Rgb(243, 255, 39),
                            Rgb(255, 255, 255),
                            Rgb(0, 255, 57),
                            ])
                    ,
                },
            Language::Php => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(119, 123, 179),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::PowerShell => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(49, 108, 185),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Processing => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(80, 80, 80),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Prolog => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Protobuf => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Green),Ansi(AnsiColors::Yellow),],
                    true_colors: None
                    ,
                },
            Language::PureScript => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Python => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Yellow),],
                    true_colors: Some(vec![Rgb(47, 105, 162),
                            Rgb(255, 217, 64),
                            ])
                    ,
                },
            Language::Qml => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Green),Ansi(AnsiColors::Default),Ansi(AnsiColors::Green),],
                    true_colors: Some(vec![Rgb(128, 195, 66),
                            Rgb(255, 255, 255),
                            Rgb(77, 117, 40),
                            ])
                    ,
                },
            Language::R => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Blue),],
                    true_colors: None
                    ,
                },
            Language::Racket => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Default),Ansi(AnsiColors::Blue),],
                    true_colors: None
                    ,
                },
            Language::Renpy => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Red),Ansi(AnsiColors::Default),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Default),Ansi(AnsiColors::Magenta),],
                    true_colors: Some(vec![Rgb(234, 219, 204),
                            Rgb(255, 127, 127),
                            Rgb(251, 238, 226),
                            Rgb(73, 95, 142),
                            Rgb(250, 228, 90),
                            Rgb(255, 255, 255),
                            Rgb(181, 163, 150),
                            ])
                    ,
                },
            Language::Ruby => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Black),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),],
                    true_colors: Some(vec![Rgb(243, 3, 1),
                            Rgb(85, 85, 85),
                            Rgb(232, 6, 3),
                            Rgb(220, 9, 4),
                            Rgb(209, 12, 6),
                            Rgb(197, 15, 7),
                            Rgb(186, 17, 9),
                            Rgb(174, 20, 10),
                            Rgb(163, 23, 12),
                            Rgb(151, 26, 13),
                            ])
                    ,
                },
            Language::Rust => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(228, 55, 23),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Sass => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Magenta),],
                    true_colors: Some(vec![Rgb(205, 103, 153),
                            ])
                    ,
                },
            Language::Scala => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),],
                    true_colors: Some(vec![Rgb(223, 63, 61),
                            Rgb(127, 12, 29),
                            ])
                    ,
                },
            Language::Scheme => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(85, 85, 85),
                            ])
                    ,
                },
            Language::Sh => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Green),],
                    true_colors: None
                    ,
                },
            Language::Solidity => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Black),Ansi(AnsiColors::Black),Ansi(AnsiColors::Black),Ansi(AnsiColors::Black),],
                    true_colors: Some(vec![Rgb(255, 255, 255),
                            Rgb(46, 46, 46),
                            Rgb(26, 26, 26),
                            Rgb(51, 51, 51),
                            Rgb(81, 81, 81),
                            ])
                    ,
                },
            Language::Sql => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Yellow),],
                    true_colors: None
                    ,
                },
            Language::Svelte => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(255, 60, 0),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Svg => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Yellow),],
                    true_colors: Some(vec![Rgb(255, 255, 255),
                            Rgb(235, 167, 31),
                            ])
                    ,
                },
            Language::Swift => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),Ansi(AnsiColors::Red),],
                    true_colors: Some(vec![Rgb(248, 129, 52),
                            Rgb(249, 119, 50),
                            Rgb(249, 109, 48),
                            Rgb(250, 99, 46),
                            Rgb(250, 89, 44),
                            Rgb(251, 80, 42),
                            Rgb(251, 70, 40),
                            Rgb(252, 60, 38),
                            Rgb(252, 50, 36),
                            Rgb(253, 40, 34),
                            ])
                    ,
                },
            Language::SystemVerilog => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Tcl => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),Ansi(AnsiColors::Cyan),],
                    true_colors: None
                    ,
                },
            Language::Tex => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Black),],
                    true_colors: None
                    ,
                },
            Language::Toml => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(156, 66, 33),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Tsx => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Magenta),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(0, 122, 204),
                            Rgb(138, 83, 166),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::TypeScript => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(0, 122, 204),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Vala => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Magenta),Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Verilog => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),Ansi(AnsiColors::Magenta),],
                    true_colors: None
                    ,
                },
            Language::Vhdl => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Green),Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::VimScript => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Green),Ansi(AnsiColors::Black),Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::VisualBasic => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(25, 95, 151),
                            Rgb(0, 78, 140),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Vue => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Green),Ansi(AnsiColors::Blue),],
                    true_colors: None
                    ,
                },
            Language::WebAssembly => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Magenta),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(101, 79, 240),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Wolfram => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Red),Ansi(AnsiColors::Default),Ansi(AnsiColors::Black),],
                    true_colors: Some(vec![Rgb(255, 10, 1),
                            Rgb(255, 255, 255),
                            Rgb(0, 0, 0),
                            ])
                    ,
                },
            Language::XSL => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Cyan),],
                    true_colors: None
                    ,
                },
            Language::Xaml => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Blue),Ansi(AnsiColors::Default),],
                    true_colors: Some(vec![Rgb(51, 120, 206),
                            Rgb(255, 255, 255),
                            ])
                    ,
                },
            Language::Xml => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),Ansi(AnsiColors::Default),Ansi(AnsiColors::Green),],
                    true_colors: None
                    ,
                },
            Language::Yaml => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            Language::Zig => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Yellow),],
                    true_colors: None
                    ,
                },
            Language::Zsh => Colors {
                    basic_colors: vec![Ansi(AnsiColors::Default),],
                    true_colors: None
                    ,
                },
            
        };
        match colors.true_colors {
            Some(true_colors) if true_color => true_colors,
            _ => colors.basic_colors,
        }
    }

    pub fn get_type(&self) -> LanguageType {
        match self {
            Language::ABNF => LanguageType::Data,
            Language::Abap => LanguageType::Programming,
            Language::Ada => LanguageType::Programming,
            Language::Agda => LanguageType::Programming,
            Language::Arduino => LanguageType::Programming,
            Language::Assembly => LanguageType::Programming,
            Language::AutoHotKey => LanguageType::Programming,
            Language::Bash => LanguageType::Programming,
            Language::C => LanguageType::Programming,
            Language::CMake => LanguageType::Programming,
            Language::CSharp => LanguageType::Programming,
            Language::Ceylon => LanguageType::Programming,
            Language::Clojure => LanguageType::Programming,
            Language::CoffeeScript => LanguageType::Programming,
            Language::ColdFusion => LanguageType::Programming,
            Language::Coq => LanguageType::Programming,
            Language::Cpp => LanguageType::Programming,
            Language::Crystal => LanguageType::Programming,
            Language::Css => LanguageType::Markup,
            Language::D => LanguageType::Programming,
            Language::Dart => LanguageType::Programming,
            Language::Dockerfile => LanguageType::Programming,
            Language::Elisp => LanguageType::Programming,
            Language::Elixir => LanguageType::Programming,
            Language::Elm => LanguageType::Programming,
            Language::Emojicode => LanguageType::Programming,
            Language::Erlang => LanguageType::Programming,
            Language::FSharp => LanguageType::Programming,
            Language::Fish => LanguageType::Programming,
            Language::Forth => LanguageType::Programming,
            Language::FortranLegacy => LanguageType::Programming,
            Language::FortranModern => LanguageType::Programming,
            Language::GdScript => LanguageType::Programming,
            Language::Glsl => LanguageType::Programming,
            Language::Go => LanguageType::Programming,
            Language::Graphql => LanguageType::Data,
            Language::Groovy => LanguageType::Programming,
            Language::Haskell => LanguageType::Programming,
            Language::Haxe => LanguageType::Programming,
            Language::Hcl => LanguageType::Programming,
            Language::Hlsl => LanguageType::Programming,
            Language::HolyC => LanguageType::Programming,
            Language::Html => LanguageType::Markup,
            Language::Idris => LanguageType::Programming,
            Language::Java => LanguageType::Programming,
            Language::JavaScript => LanguageType::Programming,
            Language::Json => LanguageType::Data,
            Language::Jsonnet => LanguageType::Programming,
            Language::Jsx => LanguageType::Programming,
            Language::Julia => LanguageType::Programming,
            Language::Jupyter => LanguageType::Programming,
            Language::Kotlin => LanguageType::Programming,
            Language::LLVM => LanguageType::Programming,
            Language::Lisp => LanguageType::Programming,
            Language::Lua => LanguageType::Programming,
            Language::Makefile => LanguageType::Programming,
            Language::Markdown => LanguageType::Prose,
            Language::Nim => LanguageType::Programming,
            Language::Nix => LanguageType::Programming,
            Language::OCaml => LanguageType::Programming,
            Language::ObjectiveC => LanguageType::Programming,
            Language::Odin => LanguageType::Programming,
            Language::Org => LanguageType::Prose,
            Language::Oz => LanguageType::Programming,
            Language::Pascal => LanguageType::Programming,
            Language::Perl => LanguageType::Programming,
            Language::Perl6 => LanguageType::Programming,
            Language::Php => LanguageType::Programming,
            Language::PowerShell => LanguageType::Programming,
            Language::Processing => LanguageType::Programming,
            Language::Prolog => LanguageType::Programming,
            Language::Protobuf => LanguageType::Programming,
            Language::PureScript => LanguageType::Programming,
            Language::Python => LanguageType::Programming,
            Language::Qml => LanguageType::Programming,
            Language::R => LanguageType::Programming,
            Language::Racket => LanguageType::Programming,
            Language::Renpy => LanguageType::Programming,
            Language::Ruby => LanguageType::Programming,
            Language::Rust => LanguageType::Programming,
            Language::Sass => LanguageType::Markup,
            Language::Scala => LanguageType::Programming,
            Language::Scheme => LanguageType::Programming,
            Language::Sh => LanguageType::Programming,
            Language::Solidity => LanguageType::Programming,
            Language::Sql => LanguageType::Data,
            Language::Svelte => LanguageType::Markup,
            Language::Svg => LanguageType::Data,
            Language::Swift => LanguageType::Programming,
            Language::SystemVerilog => LanguageType::Programming,
            Language::Tcl => LanguageType::Programming,
            Language::Tex => LanguageType::Markup,
            Language::Toml => LanguageType::Data,
            Language::Tsx => LanguageType::Programming,
            Language::TypeScript => LanguageType::Programming,
            Language::Vala => LanguageType::Programming,
            Language::Verilog => LanguageType::Programming,
            Language::Vhdl => LanguageType::Programming,
            Language::VimScript => LanguageType::Programming,
            Language::VisualBasic => LanguageType::Programming,
            Language::Vue => LanguageType::Programming,
            Language::WebAssembly => LanguageType::Programming,
            Language::Wolfram => LanguageType::Programming,
            Language::XSL => LanguageType::Programming,
            Language::Xaml => LanguageType::Data,
            Language::Xml => LanguageType::Data,
            Language::Yaml => LanguageType::Data,
            Language::Zig => LanguageType::Programming,
            Language::Zsh => LanguageType::Programming,
            
        }
    }

    pub fn get_chip_color(&self) -> DynColors {
        match self {
            Language::ABNF => Rgb(85, 94, 37),
            Language::Abap => Rgb(232, 39, 75),
            Language::Ada => Rgb(2, 248, 140),
            Language::Agda => Rgb(49, 86, 101),
            Language::Arduino => Rgb(243, 75, 125),
            Language::Assembly => Rgb(110, 76, 19),
            Language::AutoHotKey => Rgb(101, 148, 185),
            Language::Bash => Rgb(137, 224, 81),
            Language::C => Rgb(85, 85, 85),
            Language::CMake => Rgb(218, 52, 52),
            Language::CSharp => Rgb(23, 134, 0),
            Language::Ceylon => Rgb(223, 165, 53),
            Language::Clojure => Rgb(219, 88, 85),
            Language::CoffeeScript => Rgb(36, 71, 118),
            Language::ColdFusion => Rgb(237, 44, 214),
            Language::Coq => Rgb(208, 182, 140),
            Language::Cpp => Rgb(243, 75, 125),
            Language::Crystal => Rgb(0, 1, 0),
            Language::Css => Rgb(86, 61, 124),
            Language::D => Rgb(186, 89, 94),
            Language::Dart => Rgb(0, 180, 171),
            Language::Dockerfile => Rgb(56, 77, 84),
            Language::Elisp => Rgb(192, 101, 219),
            Language::Elixir => Rgb(110, 74, 126),
            Language::Elm => Rgb(96, 181, 204),
            Language::Emojicode => Rgb(96, 181, 204),
            Language::Erlang => Rgb(184, 57, 152),
            Language::FSharp => Rgb(184, 69, 252),
            Language::Fish => Rgb(74, 174, 71),
            Language::Forth => Rgb(52, 23, 8),
            Language::FortranLegacy => Rgb(77, 65, 177),
            Language::FortranModern => Rgb(77, 65, 177),
            Language::GdScript => Rgb(53, 85, 112),
            Language::Glsl => Rgb(86, 134, 165),
            Language::Go => Rgb(0, 173, 216),
            Language::Graphql => Rgb(225, 0, 152),
            Language::Groovy => Rgb(66, 152, 184),
            Language::Haskell => Rgb(94, 80, 134),
            Language::Haxe => Rgb(223, 121, 0),
            Language::Hcl => Rgb(170, 206, 96),
            Language::Hlsl => Rgb(170, 206, 96),
            Language::HolyC => Rgb(255, 239, 175),
            Language::Html => Rgb(227, 76, 38),
            Language::Idris => Rgb(179, 0, 0),
            Language::Java => Rgb(176, 114, 25),
            Language::JavaScript => Rgb(241, 224, 90),
            Language::Json => Rgb(41, 41, 41),
            Language::Jsonnet => Rgb(0, 100, 189),
            Language::Jsx => Rgb(241, 224, 90),
            Language::Julia => Rgb(162, 112, 186),
            Language::Jupyter => Rgb(218, 91, 11),
            Language::Kotlin => Rgb(169, 123, 255),
            Language::LLVM => Rgb(24, 86, 25),
            Language::Lisp => Rgb(63, 182, 139),
            Language::Lua => Rgb(0, 0, 128),
            Language::Makefile => Rgb(66, 120, 25),
            Language::Markdown => Rgb(8, 63, 161),
            Language::Nim => Rgb(255, 194, 0),
            Language::Nix => Rgb(126, 126, 255),
            Language::OCaml => Rgb(59, 225, 51),
            Language::ObjectiveC => Rgb(67, 142, 255),
            Language::Odin => Rgb(96, 175, 254),
            Language::Org => Rgb(119, 170, 153),
            Language::Oz => Rgb(250, 183, 56),
            Language::Pascal => Rgb(227, 241, 113),
            Language::Perl => Rgb(2, 152, 195),
            Language::Perl6 => Rgb(0, 0, 251),
            Language::Php => Rgb(79, 93, 149),
            Language::PowerShell => Rgb(1, 36, 86),
            Language::Processing => Rgb(0, 150, 216),
            Language::Prolog => Rgb(116, 40, 60),
            Language::Protobuf => Rgb(116, 40, 60),
            Language::PureScript => Rgb(29, 34, 45),
            Language::Python => Rgb(53, 114, 165),
            Language::Qml => Rgb(68, 165, 28),
            Language::R => Rgb(25, 140, 231),
            Language::Racket => Rgb(60, 92, 170),
            Language::Renpy => Rgb(255, 127, 127),
            Language::Ruby => Rgb(112, 21, 22),
            Language::Rust => Rgb(222, 165, 132),
            Language::Sass => Rgb(165, 59, 112),
            Language::Scala => Rgb(194, 45, 64),
            Language::Scheme => Rgb(30, 74, 236),
            Language::Sh => Rgb(137, 224, 81),
            Language::Solidity => Rgb(170, 103, 70),
            Language::Sql => Rgb(227, 140, 0),
            Language::Svelte => Rgb(255, 62, 0),
            Language::Svg => Rgb(255, 153, 0),
            Language::Swift => Rgb(240, 81, 56),
            Language::SystemVerilog => Rgb(218, 225, 194),
            Language::Tcl => Rgb(228, 204, 152),
            Language::Tex => Rgb(61, 97, 23),
            Language::Toml => Rgb(156, 66, 33),
            Language::Tsx => Rgb(43, 116, 137),
            Language::TypeScript => Rgb(43, 116, 137),
            Language::Vala => Rgb(165, 109, 226),
            Language::Verilog => Rgb(178, 183, 248),
            Language::Vhdl => Rgb(173, 178, 203),
            Language::VimScript => Rgb(25, 159, 75),
            Language::VisualBasic => Rgb(148, 93, 183),
            Language::Vue => Rgb(25, 159, 75),
            Language::WebAssembly => Rgb(4, 19, 59),
            Language::Wolfram => Rgb(221, 17, 0),
            Language::XSL => Rgb(235, 140, 235),
            Language::Xaml => Rgb(0, 96, 172),
            Language::Xml => Rgb(0, 96, 172),
            Language::Yaml => Rgb(203, 23, 30),
            Language::Zig => Rgb(236, 145, 92),
            Language::Zsh => Rgb(137, 224, 81),
            
        }
    }

    pub fn get_chip_icon(&self, use_nerd_fonts: bool) -> char {
        if use_nerd_fonts {
            match self {
                Language::ABNF => DEFAULT_CHIP_ICON,
                Language::Abap => DEFAULT_CHIP_ICON,
                Language::Ada => '\u{E6B5}',
                Language::Agda => DEFAULT_CHIP_ICON,
                Language::Arduino => '\u{F34B}',
                Language::Assembly => '\u{E6AB}',
                Language::AutoHotKey => DEFAULT_CHIP_ICON,
                Language::Bash => '\u{EBCA}',
                Language::C => '\u{E61E}',
                Language::CMake => DEFAULT_CHIP_ICON,
                Language::CSharp => '\u{E648}',
                Language::Ceylon => DEFAULT_CHIP_ICON,
                Language::Clojure => '\u{E768}',
                Language::CoffeeScript => '\u{E751}',
                Language::ColdFusion => '\u{E645}',
                Language::Coq => DEFAULT_CHIP_ICON,
                Language::Cpp => '\u{E61D}',
                Language::Crystal => '\u{E62F}',
                Language::Css => '\u{E749}',
                Language::D => '\u{E7AF}',
                Language::Dart => '\u{E64C}',
                Language::Dockerfile => '\u{F308}',
                Language::Elisp => '\u{E632}',
                Language::Elixir => '\u{E62D}',
                Language::Elm => '\u{E62C}',
                Language::Emojicode => '\u{f1044}',
                Language::Erlang => '\u{E7B1}',
                Language::FSharp => '\u{E7A7}',
                Language::Fish => '\u{EE41}',
                Language::Forth => '\u{229E}',
                Language::FortranLegacy => '\u{f121a}',
                Language::FortranModern => '\u{f121a}',
                Language::GdScript => '\u{E65F}',
                Language::Glsl => DEFAULT_CHIP_ICON,
                Language::Go => '\u{E627}',
                Language::Graphql => '\u{e662}',
                Language::Groovy => '\u{E775}',
                Language::Haskell => '\u{E777}',
                Language::Haxe => '\u{E666}',
                Language::Hcl => DEFAULT_CHIP_ICON,
                Language::Hlsl => '\u{229E}',
                Language::HolyC => '\u{E61E}',
                Language::Html => '\u{E736}',
                Language::Idris => DEFAULT_CHIP_ICON,
                Language::Java => '\u{E738}',
                Language::JavaScript => '\u{F2EE}',
                Language::Json => '\u{eb0f}',
                Language::Jsonnet => DEFAULT_CHIP_ICON,
                Language::Jsx => '\u{F2EE}',
                Language::Julia => '\u{E624}',
                Language::Jupyter => DEFAULT_CHIP_ICON,
                Language::Kotlin => '\u{E634}',
                Language::LLVM => DEFAULT_CHIP_ICON,
                Language::Lisp => '\u{E6B0}',
                Language::Lua => '\u{E620}',
                Language::Makefile => '\u{E673}',
                Language::Markdown => '\u{E73E}',
                Language::Nim => '\u{E677}',
                Language::Nix => '\u{f313}',
                Language::OCaml => '\u{E67A}',
                Language::ObjectiveC => DEFAULT_CHIP_ICON,
                Language::Odin => DEFAULT_CHIP_ICON,
                Language::Org => '\u{E633}',
                Language::Oz => DEFAULT_CHIP_ICON,
                Language::Pascal => DEFAULT_CHIP_ICON,
                Language::Perl => '\u{E67E}',
                Language::Perl6 => DEFAULT_CHIP_ICON,
                Language::Php => '\u{f031f}',
                Language::PowerShell => '\u{f0a0a}',
                Language::Processing => DEFAULT_CHIP_ICON,
                Language::Prolog => '\u{E7A1}',
                Language::Protobuf => DEFAULT_CHIP_ICON,
                Language::PureScript => '\u{E630}',
                Language::Python => '\u{E73C}',
                Language::Qml => DEFAULT_CHIP_ICON,
                Language::R => '\u{E68A}',
                Language::Racket => DEFAULT_CHIP_ICON,
                Language::Renpy => DEFAULT_CHIP_ICON,
                Language::Ruby => '\u{E739}',
                Language::Rust => '\u{E7A8}',
                Language::Sass => '\u{E74B}',
                Language::Scala => '\u{E737}',
                Language::Scheme => '\u{E6B1}',
                Language::Sh => '\u{f1183}',
                Language::Solidity => DEFAULT_CHIP_ICON,
                Language::Sql => '\u{E737}',
                Language::Svelte => '\u{E697}',
                Language::Svg => '\u{f0721}',
                Language::Swift => '\u{E755}',
                Language::SystemVerilog => '\u{F4BC}',
                Language::Tcl => '\u{e7c4}',
                Language::Tex => '\u{E69B}',
                Language::Toml => '\u{E6B2}',
                Language::Tsx => '\u{E69D}',
                Language::TypeScript => '\u{E69D}',
                Language::Vala => DEFAULT_CHIP_ICON,
                Language::Verilog => '\u{F4BC}',
                Language::Vhdl => '\u{F4BC}',
                Language::VimScript => '\u{E7C5}',
                Language::VisualBasic => DEFAULT_CHIP_ICON,
                Language::Vue => '\u{E6A0}',
                Language::WebAssembly => '\u{E6A1}',
                Language::Wolfram => DEFAULT_CHIP_ICON,
                Language::XSL => '\u{f05c0}',
                Language::Xaml => '\u{f0673}',
                Language::Xml => '\u{f05c0}',
                Language::Yaml => '\u{E6A8}',
                Language::Zig => '\u{E6A9}',
                Language::Zsh => '\u{f1183}',
                
            }
        } else {
            DEFAULT_CHIP_ICON
        }
    }
}

fn __loc(language_type: &tokei::LanguageType, language: &tokei::Language) -> usize {
    match language_type {
        tokei::LanguageType::ABNF => language.code,
        tokei::LanguageType::Abap => language.code,
        tokei::LanguageType::Ada => language.code,
        tokei::LanguageType::Agda => language.code,
        tokei::LanguageType::Arduino => language.code,
        tokei::LanguageType::Assembly => language.code,
        tokei::LanguageType::AutoHotKey => language.code,
        tokei::LanguageType::Bash => language.code,
        tokei::LanguageType::C => language.code,
        tokei::LanguageType::CMake => language.code,
        tokei::LanguageType::CSharp => language.code,
        tokei::LanguageType::Ceylon => language.code,
        tokei::LanguageType::Clojure => language.code,
        tokei::LanguageType::CoffeeScript => language.code,
        tokei::LanguageType::ColdFusion => language.code,
        tokei::LanguageType::Coq => language.code,
        tokei::LanguageType::Cpp => language.code,
        tokei::LanguageType::Crystal => language.code,
        tokei::LanguageType::Css => language.code,
        tokei::LanguageType::D => language.code,
        tokei::LanguageType::Dart => language.code,
        tokei::LanguageType::Dockerfile => language.code,
        tokei::LanguageType::Elisp => language.code,
        tokei::LanguageType::Elixir => language.code,
        tokei::LanguageType::Elm => language.code,
        tokei::LanguageType::Emojicode => language.code,
        tokei::LanguageType::Erlang => language.code,
        tokei::LanguageType::FSharp => language.code,
        tokei::LanguageType::Fish => language.code,
        tokei::LanguageType::Forth => language.code,
        tokei::LanguageType::FortranLegacy => language.code,
        tokei::LanguageType::FortranModern => language.code,
        tokei::LanguageType::GdScript => language.code,
        tokei::LanguageType::Glsl => language.code,
        tokei::LanguageType::Go => language.code,
        tokei::LanguageType::Graphql => language.code,
        tokei::LanguageType::Groovy => language.code,
        tokei::LanguageType::Haskell => language.code,
        tokei::LanguageType::Haxe => language.code,
        tokei::LanguageType::Hcl => language.code,
        tokei::LanguageType::Hlsl => language.code,
        tokei::LanguageType::HolyC => language.code,
        tokei::LanguageType::Html => language.code,
        tokei::LanguageType::Idris => language.code,
        tokei::LanguageType::Java => language.code,
        tokei::LanguageType::JavaScript => language.code,
        tokei::LanguageType::Json => language.code,
        tokei::LanguageType::Jsonnet => language.code,
        tokei::LanguageType::Jsx => language.code,
        tokei::LanguageType::Julia => language.code,
        tokei::LanguageType::Jupyter => language.code,
        tokei::LanguageType::Kotlin => language.code,
        tokei::LanguageType::LLVM => language.code,
        tokei::LanguageType::Lisp => language.code,
        tokei::LanguageType::Lua => language.code,
        tokei::LanguageType::Makefile => language.code,
        tokei::LanguageType::Markdown => language.code + language.comments,
        tokei::LanguageType::Nim => language.code,
        tokei::LanguageType::Nix => language.code,
        tokei::LanguageType::OCaml => language.code,
        tokei::LanguageType::ObjectiveC => language.code,
        tokei::LanguageType::Odin => language.code,
        tokei::LanguageType::Org => language.code,
        tokei::LanguageType::Oz => language.code,
        tokei::LanguageType::Pascal => language.code,
        tokei::LanguageType::Perl => language.code,
        tokei::LanguageType::Perl6 => language.code,
        tokei::LanguageType::Php => language.code,
        tokei::LanguageType::PowerShell => language.code,
        tokei::LanguageType::Processing => language.code,
        tokei::LanguageType::Prolog => language.code,
        tokei::LanguageType::Protobuf => language.code,
        tokei::LanguageType::PureScript => language.code,
        tokei::LanguageType::Python => language.code,
        tokei::LanguageType::Qml => language.code,
        tokei::LanguageType::R => language.code,
        tokei::LanguageType::Racket => language.code,
        tokei::LanguageType::Renpy => language.code,
        tokei::LanguageType::Ruby => language.code,
        tokei::LanguageType::Rust => language.code,
        tokei::LanguageType::Sass => language.code,
        tokei::LanguageType::Scala => language.code,
        tokei::LanguageType::Scheme => language.code,
        tokei::LanguageType::Sh => language.code,
        tokei::LanguageType::Solidity => language.code,
        tokei::LanguageType::Sql => language.code,
        tokei::LanguageType::Svelte => language.code,
        tokei::LanguageType::Svg => language.code,
        tokei::LanguageType::Swift => language.code,
        tokei::LanguageType::SystemVerilog => language.code,
        tokei::LanguageType::Tcl => language.code,
        tokei::LanguageType::Tex => language.code,
        tokei::LanguageType::Toml => language.code,
        tokei::LanguageType::Tsx => language.code,
        tokei::LanguageType::TypeScript => language.code,
        tokei::LanguageType::Vala => language.code,
        tokei::LanguageType::Verilog => language.code,
        tokei::LanguageType::Vhdl => language.code,
        tokei::LanguageType::VimScript => language.code,
        tokei::LanguageType::VisualBasic => language.code,
        tokei::LanguageType::Vue => language.code,
        tokei::LanguageType::WebAssembly => language.code,
        tokei::LanguageType::Wolfram => language.code,
        tokei::LanguageType::XSL => language.code,
        tokei::LanguageType::Xaml => language.code,
        tokei::LanguageType::Xml => language.code,
        tokei::LanguageType::Yaml => language.code,
        tokei::LanguageType::Zig => language.code,
        tokei::LanguageType::Zsh => language.code,
        
        _ => unimplemented!("Language Type {:?}", language_type),
    }
}


fn __stats_loc(language_type: &tokei::LanguageType, stats: &tokei::CodeStats) -> usize {
    match language_type {
	tokei::LanguageType::Markdown => stats.code + stats.comments,
	    
	_ => stats.code
    }
}


